@@ -10,32 +10,39 @@
  * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/auth', ['oxguard/oxguard_core', 'oxguard/util',
-                        'gettext!oxguard'], function (core, util, gt) {
+    'gettext!oxguard'], function (core, util, gt) {
     'use strict';
 
     var auth_core = {};
 
     // Perform auth against Guard server
     // Return auth code if any
-    auth_core.authorize = function authorize(baton, prompt, minSingleUse, forceRelogin) {
+    auth_core.authorize = function authorize(baton, o) {
+        var options = _.extend({}, o);
         var def = $.Deferred();
         if (isFile(baton) && core.hasLocalKeys()) {  // If file and local, we need to pull the session keys, etc
             require(['pgp_local/localHandler'], function (local) {
-                local.fileFound(baton, prompt, minSingleUse)
+                local.fileFound(baton, options.optPrompt, options.minSingleUse)
                 .done(function (auth) {
                     def.resolve(auth);
+                    if (_.isFunction(options.callback)) {
+                        options.callback(auth);
+                    }
                 })
                 .fail(function () {
-                    checkAuth(prompt, minSingleUse, forceRelogin, def);
+                    checkAuth(options, def);
+                    if (_.isFunction(options.failAuthCheck)) {
+                        options.failAuthCheck();
+                    }
                 });
             });
         } else {
-            checkAuth(prompt, minSingleUse, forceRelogin, def);
+            checkAuth(options, def);
         }
         return def;
     };
 
-    function isFile (baton) {
+    function isFile(baton) {
         var file;
         if (_.isArray(baton)) {
             file = {
@@ -45,40 +52,52 @@ define('oxguard/auth', ['oxguard/oxguard_core', 'oxguard/util',
             file = baton;
         }
         if (file && file.data) {
-            if (file.data.filename || file.data.source == 'drive' || file.data.source == 'guardDrive') return true;
+            if (file.data.filename || file.data.source === 'drive' || file.data.source === 'guardDrive') return true;
         }
         return false;
     }
 
-    function checkAuth (prompt, minSingleUse, forceRelogin, def) {
+    function doAuthCheck(options, def) {
+        if (options.forceRelogin) {  // If we must relogin, show password prompt
+            promptPassword(options, def);
+        } else { // Else check if we have authentication already in session
+            core.checkAuth(options)
+            .done(function (data) {
+                def.resolve(data.auth);
+            })
+            .fail(function () {
+                promptPassword(options, def);
+            });
+        }
+    }
+    function checkAuth(options, def) {
+        // If we have known auth code, then proceed without deferred action (needed for tabs)
+        if (util.hasStoredPassword()) {
+            doAuthCheck(options, def);
+            return;
+        }
         ensureSetup().then(function () {
-            if (forceRelogin) {  // If we must relogin, show password prompt
-                promptPassword (prompt, minSingleUse, def);
-            } else { // Else check if we have authentication already in session
-                core.checkAuth()
-                .done(function (data) {
-                    def.resolve(data.auth);
-                })
-                .fail(function () {
-                    promptPassword (prompt, minSingleUse, def);
-                });
-            }
+            doAuthCheck(options, def);
         }, def.reject);
     }
 
     // Display password prompt to authorize
-    function promptPassword (prompt, minSingleUse, def) {
-        if (prompt === undefined) {
-            prompt = gt('Enter %s security password', window.oxguarddata.productName);
-        }
-        core.getPassword(prompt, true)  //Get password
+    function promptPassword(options, def) {
+        var prompt = options.optPrompt ? options.optPrompt : gt('Enter %s security password', window.oxguarddata.productName);
+        core.getPassword(prompt, true, options)  //Get password
         .done(function (passdata) {
-            if (passdata.duration > -1 || minSingleUse) {
+            if (passdata.duration > -1 || options.minSingleUse) {
                 core.savePassword(passdata.password, passdata.duration)
                 .done(function (data) {
                     def.resolve(data.auth);
+                    if (_.isFunction(options.callback)) {
+                        options.callback(data.auth);
+                    }
                 })
                 .fail(function (data) {
+                    if (_.isFunction(options.failAuthCallback)) {
+                        options.failAuthCallback();
+                    }
                     handleFail(data.auth);
                     def.reject(data.auth);
                 });
@@ -86,10 +105,17 @@ define('oxguard/auth', ['oxguard/oxguard_core', 'oxguard/util',
                 core.auth(ox.user_id, passdata.password)
                 .done(function (data) {
                     if (data.auth.length > 20 && !(/Error:/i.test(data.auth))) {
+                        if (_.isFunction(options.callback)) {
+                            options.callback(data.auth);
+                        }
                         def.resolve(data.auth);
                     } else {
+                        if (_.isFunction(options.failAuthCallback)) {
+                            options.failAuthCallback();
+                        }
                         handleFail(data.auth);
                         def.reject(data.auth);
+
                     }
                 });
             }
@@ -122,7 +148,7 @@ define('oxguard/auth', ['oxguard/oxguard_core', 'oxguard/util',
         var def = $.Deferred();
         ensureLoaded().then(function () {
             if (!util.isGuardConfigured()) {
-                require (['oxguard/core/createKeys'], function (keys) {
+                require(['oxguard/core/createKeys'], function (keys) {
                     core.metrics('drive', 'create-keys');
                     keys.createKeysWizard()
                     .then(def.resolve, def.reject);
@@ -146,18 +172,18 @@ define('oxguard/auth', ['oxguard/oxguard_core', 'oxguard/util',
         return def;
     }
 
-    function handleFail (auth) {
-        require (['io.ox/core/notifications'], function (notifications) {
+    function handleFail(auth) {
+        require(['io.ox/core/notifications'], function (notifications) {
             switch (auth.toLowerCase()) {
-            case 'bad password':
-                notifications.yell('error', gt('Bad password'));
-                return;
-            case 'lockout':
-                notifications.yell('error', gt('Account Locked out'));
-                return;
-            default:
-                notifications.yell('error', gt('Unspecified error') + '\n' + auth);
-                return;
+                case 'bad password':
+                    notifications.yell('error', gt('Bad password'));
+                    return;
+                case 'lockout':
+                    notifications.yell('error', gt('Account Locked out'));
+                    return;
+                default:
+                    notifications.yell('error', gt('Unspecified error') + '\n' + auth);
+                    return;
             }
         });
     }
