@@ -169,7 +169,7 @@ define('oxguard/core/createKeys', [
                 .toggleClass('has-warning', strength === 'weak');
         },
         handleError: function (error) {
-            require (['io.ox/core/notifications'], function (notify) {
+            require(['io.ox/core/notifications'], function (notify) {
                 notify.yell('error', error);
             });
         },
@@ -194,7 +194,7 @@ define('oxguard/core/createKeys', [
                         .addClass('col-sm-12 col-md-4')
                         .text(gt('Password')),
                     $('<div>').addClass('col-sm-12 col-md-8').append(
-                            new PasswordView.view({ 'id': 'newogpassword', 'validate': true }).getProtected()
+                        new PasswordView.view({ 'id': 'newogpassword', 'validate': true }).getProtected()
                     ),
                     $('<div>').addClass('col-sm-12 error-msg')
                 ),
@@ -203,7 +203,7 @@ define('oxguard/core/createKeys', [
                         .addClass('col-sm-12 col-md-4')
                         .text(gt('Confirm')),
                     $('<div>').addClass('col-sm-12 col-md-8').append(
-                            new PasswordView.view({ 'id': 'newogpassword2' }).getProtected()
+                        new PasswordView.view({ 'id': 'newogpassword2' }).getProtected()
                     ),
                     $('<div>').addClass('col-sm-12 error-msg')
                 )
@@ -220,14 +220,14 @@ define('oxguard/core/createKeys', [
         renderRecoverMailPrompt: function (el) {
             if (window.oxguarddata.settings.noRecovery === true) {
                 el.append($('<hr style="padding:10px;"/>'),
-                        $('<p class="oxguard_warning">').text(gt('Warning: This password for encryption cannot be restored or recovered in any way.  If forgotten, all encrypted data will be lost')));
+                    $('<p class="oxguard_warning">').text(gt('Warning: This password for encryption cannot be restored or recovered in any way.  If forgotten, all encrypted data will be lost')));
                 return this;  // If no recovery set, don't add prompt for second password
             }
             if (this.model.get('initialSetup')) {
                 el.append(
                     $('<hr style="padding:10px;"/>'),
                     $('<p>').text(gt('Please enter a secondary email address in case you need to reset your password.')),
-                        $('<div>').addClass('form-group email').append(
+                    $('<div>').addClass('form-group email').append(
                         $('<label>').addClass('col-sm-12 col-md-4').text(gt('Email:')),
                         $('<div>').addClass('col-sm-12 col-md-8').append(
                             $('<input name="recoverymail">').addClass('form-control')
@@ -278,7 +278,7 @@ define('oxguard/core/createKeys', [
     // Prompt for creating master keys for this user if not yet created.
     function createKeys() {
         var def = $.Deferred(),
-        view = new CreateKeysView();
+            view = new CreateKeysView();
 
         var dialog = new ModalView({
             async: true,
@@ -332,7 +332,7 @@ define('oxguard/core/createKeys', [
     }
 
     function validateEmail(email) {
-        var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
+        var re = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
         return re.test(email);
     }
 
