@@ -8,18 +8,18 @@
  *     Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/core/emailverify', [
-'gettext!oxguard',
-'less!oxguard/core/style'
+    'gettext!oxguard',
+    'less!oxguard/core/style'
 ], function (gt) {
     'use strict';
 
-    function validate (email) {
-        return (email.match(/[a-z0-9!#$%&'*+\/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+\/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[^\s\.]*)?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/i));
+    function validate(email) {
+        return (email.match(/[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[^\s.]*)?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/i));
     }
 
-    function setValidate (e1, hint) {
+    function setValidate(e1, hint) {
         $(e1).on('input', function () {
-            if (validate ($(e1).val())) {
+            if (validate($(e1).val())) {
                 $(e1).removeClass('oxguard_badpass');
                 if (hint) $(hint).html('');
             } else {
@@ -31,7 +31,7 @@ define('oxguard/core/emailverify', [
         });
     }
 
-    function autoCompare (e1, e2, hint) {
+    function autoCompare(e1, e2, hint) {
         $(e2).on('input', function () {
             if ($(e1).val() === $(e2).val()) {
                 $(e2).removeClass('oxguard_badpass');
