@@ -12,7 +12,7 @@ define('oxguard/core/log', [
 ], function (http) {
     'use strict';
 
-    function log (e, o) {
+    function log(e, o) {
         var collection = http.log();
         collection.add(new Backbone.Model(e).set({
             params: o.params,
@@ -23,9 +23,9 @@ define('oxguard/core/log', [
         }));
     }
 
-    function fail (r, url, params, data) {
+    function fail(r, url, params, data) {
         var errorText = r.statusText;
-        if (r.status === 406 || r.status == 500) {
+        if (r.status === 406 || r.status === 500) {
             errorText = r.status + ': ' + errorText + ' - ' + r.responseText;
             r.status = undefined;
         }
@@ -38,17 +38,17 @@ define('oxguard/core/log', [
             url: url,
             data: data
         };
-        log (e, o);
+        log(e, o);
     }
 
-    function slow (took, url, params, data) {
+    function slow(took, url, params, data) {
         var e = { error: 'Took: ' + (Math.round(took / 100) / 10) + 's', status: 200, took: took };
         var o = {
             params: params,
             url: url,
             data: data
         };
-        log (e, o);
+        log(e, o);
     }
 
     return {
