@@ -15,7 +15,7 @@ define('oxguard/core/passwords', [
 
     // Compare two el1 to el2 values whenever el1 changes.  If hint
     // has value, then color and text if different
-    function passwordCompare (el1, el2, hint) {
+    function passwordCompare(el1, el2, hint) {
         var el1ToCompare = el1.getForCompare ? el1.getForCompare() : el1;  // Check if password View
         var el2ToCompare = el2.getForCompare ? el2.getForCompare() : el2;
         $(el1ToCompare).on('input', function () {
@@ -28,10 +28,8 @@ define('oxguard/core/passwords', [
                         hint.removeClass('oxguard_hint_bad').removeClass('oxguard_hint_good').removeClass('oxguard_hint_warn');
                         hint.addClass('oxguard_hint_bad').text(gt('Passwords not equal'));
                     }
-                } else {
-                    if (hint !== undefined) {
-                        hint.text('');
-                    }
+                } else if (hint !== undefined) {
+                    hint.text('');
                 }
             }
         });
@@ -84,12 +82,13 @@ define('oxguard/core/passwords', [
     }
 
     // Create password prompt that defeats the autocomplete
-    function createPasswordInput (id, name, options) {
+    // Depreciated.  Use PasswordView
+    function createPasswordInput(id, name, options) {
         if (name === undefined) name = id;
         var passString = '<input ' +
         (name === undefined ? '' : 'name = "' + name + '" ') +
         (id === undefined ? '' : 'id = "' + id + '" ') +
-                'type="password" autocomplete="off" readonly onfocus="this.removeAttribute(\'readonly\');"' +
+                'type="password" autocomplete="new-password" readonly onfocus="this.removeAttribute(\'readonly\');"' +
         (options === undefined ? '' : options) +
         '/>';
         return $(passString);
