@@ -25,18 +25,18 @@ define('oxguard/core/tempPassword', [
         if (firstprompt) return;
         firstprompt = true;
         var dialog = new dialogs.ModalDialog({ width: 450, center: true, enter: 'okpass' });
-        var isnew = window.oxguarddata['new'];
+        var isnew = window.oxguarddata.new;
         var hasPin = window.oxguarddata.pin;
         var explain = '';
         if (isnew) {
             //#. %s product name
             dialog.header($('<h4>').text(gt('First %s Security Use', window.oxguarddata.productName)));
-            explain  = $('<div>');
+            explain = $('<div>');
             explain.append($('<p>').append(gt('You have been sent an email using %s to secure the contents', window.oxguarddata.productName)));
             explain.append($('<p>').append(gt('Please select a new password for use with %s.  This password will be used to open encrypted emails and files that may be sent to you.', window.oxguarddata.productName)));
         } else {
             //#. %s product name
-            dialog.header($('<h4>').text(gt('First %s Security Password Use', window.oxguarddata.productName)));
+            dialog.header($('<h4>').text(gt('First %s Security Use', window.oxguarddata.productName)));
             explain = $('<div><p>' + gt('Please change the initial temporary %s security password that was sent to you in a separate email.', window.oxguarddata.productName) + '</p></div>');
         }
 
@@ -60,7 +60,7 @@ define('oxguard/core/tempPassword', [
         .append($('<tr><td class="pw"><label for="newogpassword2">' + gt('Confirm New') + ':</label></td></tr>').append(td2).append('<td></td>'));
         passdiv.append(table);
         dialog.getBody().append(explain).append(passdiv);
-        require (['oxguard/core/passwords'], function (pass) {
+        require(['oxguard/core/passwords'], function (pass) {
             pass.passwordCheck(newogpassword, hint);
             pass.passwordCompare(newogpassword2, newogpassword, hint);
         });
@@ -82,14 +82,14 @@ define('oxguard/core/tempPassword', [
             var email1 = $('<input id="recoveryemail" name="recoveryemail" class="form-control password_prompt"/>');
             var email2 = $('<input id="verifyemail" name="verifyemail" class="form-control password_prompt"/>');
             var hint2 = $('<td>');
-            var row = $('<tr>').append($('<td class="pw"><label for="recoveryemail">' + gt ('Email:') + '</label></td>')).append($('<td>').append(email1)).append(hint2);
-            var row2 = $('<tr>').append($('<td class="pw"><label for="verifyemail">' + gt ('Verify:') + '</label></td>')).append($('<td>').append(email2));
+            var row = $('<tr>').append($('<td class="pw"><label for="recoveryemail">' + gt('Email:') + '</label></td>')).append($('<td>').append(email1)).append(hint2);
+            var row2 = $('<tr>').append($('<td class="pw"><label for="verifyemail">' + gt('Verify:') + '</label></td>')).append($('<td>').append(email2));
             table2.append(row).append(row2);
             email1.focus(function () {
                 dialog.getBody().animate({ scrollTop: $('#recoveryemail').offset().top });
             });
             dialog.getBody().append(rule).append(recovery).append(table2);
-            require (['oxguard/core/emailverify'], function (verify) {
+            require(['oxguard/core/emailverify'], function (verify) {
                 verify.setValidate(email1, hint2);
                 verify.autoCompare(email1, email2, hint2);
             });
@@ -108,7 +108,7 @@ define('oxguard/core/tempPassword', [
         })
         .on('okpass', function () {
             firstprompt = false;
-            var oldpass = $('#oldogpassword').val() === undefined ? '' : $('input[name="oldogpassword"]').val();
+            var oldpass = $('#oldogpassword').val() === undefined ? '' : $('#oldogpassword').val();
             var pass1 = $('#newogpassword').val();
             var pass2 = $('#newogpassword2').val();
             var pin = hasPin ? $('#pinInput').val() : '';
@@ -125,6 +125,7 @@ define('oxguard/core/tempPassword', [
                 return;
             }
             var defaultSendAddress = $.trim(mailSettings.get('defaultSendAddress', ''));
+
             var userdata = {
                 newpass: pass1,
                 oldpass: oldpass,
@@ -140,7 +141,7 @@ define('oxguard/core/tempPassword', [
                 return;
             }
             if (validateEmail(emailaddr)) userdata.email = emailaddr;
-            require (['io.ox/core/notifications'], function (notifications) {
+            require(['io.ox/core/notifications'], function (notifications) {
                 http.post(ox.apiRoot + '/oxguard/login?action=changepass', '', userdata)
                 .done(function (data) {
                     if (typeof data === 'string') data = $.parseJSON(data);
@@ -161,12 +162,12 @@ define('oxguard/core/tempPassword', [
                         window.oxguarddata.passcode = null;
                         window.oxguarddata.recoveryAvail = window.oxguarddata.recovery = !window.oxguarddata.settings.noRecovery;
                         core.saveAuthToSession(data.auth, -1).then(function () {
-                            if (go) go (baton, pass1, index);
+                            if (go) go(baton, pass1, index);
                         });
                         notifications.yell('success', gt('Password changed successfully'));
                         window.oxguarddata.pin = false;
                         updateSecondary();
-                        window.oxguarddata['new'] = false;
+                        window.oxguarddata.new = false;
                         // Complete, now offer tour
                         require(['io.ox/core/capabilities', 'io.ox/core/tk/wizard', 'oxguard/tour/main'], function (capabilities, Tour) {
                             if (capabilities.has('guard-mail')) { // only run tour if has guard-mail
@@ -209,9 +210,9 @@ define('oxguard/core/tempPassword', [
                     $('#newogpassword').focus();
                 }
             } else
-                if (!_.device('ios')) {
-                    $('#oldogpassword').focus();
-                }
+            if (!_.device('ios')) {
+                $('#oldogpassword').focus();
+            }
             if (errors) {
                 if ($('#recoveryemail').length > 0) {
                     dialog.getBody().animate({ scrollTop: $('#recoveryemail').offset().top });
@@ -222,11 +223,11 @@ define('oxguard/core/tempPassword', [
             }
             window.setTimeout(function () {
                 var j = 0;
-                $('.pw').each(function (i,v) {
+                $('.pw').each(function (i, v) {
                     var w = $(v).width();
                     if (w > j) j = w;
                 });
-                $('.pw').each(function (i,v) {
+                $('.pw').each(function (i, v) {
                     $(v).width(j);
                 });
                 var email = $('input[name="recoveryemail"]'); // Watch email entry for valid
@@ -237,19 +238,19 @@ define('oxguard/core/tempPassword', [
                         email.css('background-color', 'rgb(253, 187, 179)');
                     }
                 });
-            },0);
+            }, 0);
         });
     }
 
     // Valide legit email address
     function validateEmail(email) {
-        var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
+        var re = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
         return re.test(email);
     }
 
-    function updateSecondary () {
+    function updateSecondary() {
         if ($('#currentsecondary').length > 0) {
-            require (['oxguard/settings/pane'], function (settingsPage) {
+            require(['oxguard/settings/pane'], function (settingsPage) {
                 settingsPage.updateEmail();
             });
         }
