@@ -16,8 +16,8 @@ define('oxguard/files/register', [
     'io.ox/core/dropzone',
     'oxguard/auth',
     'gettext!oxguard',
-    'io.ox/core/extPatterns/links'
-], function (ext, capabilities, oxguard, folderAPI, util, dropzone, auth_core, gt, links) {
+    'io.ox/backbone/views/actions/util'
+], function (ext, capabilities, oxguard, folderAPI, util, dropzone, auth_core, gt, actionsUtil) {
 
     'use strict';
 
@@ -33,7 +33,7 @@ define('oxguard/files/register', [
                     download.click(function (ev) {
                         ev.preventDefault();
                         auth_core.authorize(baton).then(function (data) {
-                            require (['oxguard/files/downloader'], function (downloader) {
+                            require(['oxguard/files/downloader'], function (downloader) {
                                 metrics('guard', 'decrypt & download');
                                 downloader.viewFile(baton, 'download', data);
                             });
@@ -49,70 +49,90 @@ define('oxguard/files/register', [
 
     //////   Links
     // Add link for add and encrypt local file
-    new links.ActionLink('io.ox/files/links/toolbar/default', {
+    new actionsUtil.Action('io.ox/files/toolbar/new', {
         index: 110,
         id: 'uploadEncrypt',
-        label: gt('Add and encrypt local file'),
+        title: gt('Add and encrypt local file'),
         ref: 'io.ox/files/actions/uploadEncrypt'
     });
 
-    ext.point('io.ox/files/classic-toolbar/links').extend(new links.Link({
+    ext.point('io.ox/files/toolbar/links').extend({
         id: 'remencrypt',
         index: 550,
-        label: gt('Remove encryption'),
+        title: gt('Remove encryption'),
         ref: 'oxguard/remencrypt',
         mobile: 'lo',
         section: 'guard'
-    }));
+    });
 
-    ext.point('io.ox/files/classic-toolbar/links').extend(new links.Link({
+    ext.point('io.ox/files/toolbar/links').extend({
         id: 'encrypt',
         index: 550,
-        label: gt('Encrypt'),
+        title: gt('Encrypt'),
         ref: 'oxguard/encrypt',
         mobile: 'lo',
         section: 'guard'
-    }));
+    });
+
+    ext.point('io.ox/files/toolbar/links').extend({
+        id: 'sendcopy',
+        index: 1200,
+        prio: 'lo',
+        mobile: 'lo',
+        title: gt('Send by mail'),
+        ref: 'oxguard/sendcopy',
+        section: 'share'
+    });
 
     // Mobile links
-    ext.point('io.ox/files/links/inline').extend(new links.Link({
+    ext.point('io.ox/files/links/inline').extend({
         id: 'encrypt',
         index: 1000,
         prio: 'hi',
         mobile: 'lo',
-        label: gt('Encrypt'),
+        title: gt('Encrypt'),
         ref: 'oxguard/encrypt'
-    }));
+    });
 
-    ext.point('io.ox/files/links/inline').extend(new links.Link({
+    ext.point('io.ox/files/links/inline').extend({
         id: 'remencrypt',
         index: 1000,
         prio: 'hi',
         mobile: 'lo',
-        label: gt('Remove encryption'),
+        title: gt('Remove encryption'),
         ref: 'oxguard/remencrypt'
-    }));
+    });
+
+    ext.point('io.ox/files/links/inline').extend({
+        id: 'sendcopy',
+        index: 1200,
+        prio: 'hi',
+        mobile: 'lo',
+        title: gt('Send by mail'),
+        ref: 'oxguard/sendcopy',
+        section: 'share'
+    });
 
     // Context menu
 
-    ext.point('io.ox/core/file/contextmenu/default/items').extend(
+    ext.point('io.ox/files/listview/contextmenu').extend(
         {
             id: 'encrypt',
             index: 1450,
             ref: 'oxguard/encrypt',
             section: '25',
-            label: gt('Encrypt')
+            title: gt('Encrypt')
         }
     );
 
-    ext.point('io.ox/core/file/contextmenu/default/items').extend(
+    ext.point('io.ox/files/listview/contextmenu').extend(
 
         {
             id: 'decrypt',
             index: 1450,
             ref: 'oxguard/remencrypt',
             section: '25',
-            label: gt('Remove encryption')
+            title: gt('Remove encryption')
         }
     );
 
@@ -120,9 +140,10 @@ define('oxguard/files/register', [
     ext.point('io.ox/files/actions/send').extend({
         id: 'og_stop_send',
         index: 1,
-        requires: function (e) {
-            if (e.collection.has('some', 'items') && !_.isEmpty(e.baton.data)) {
-                var toCheck = e.baton.models === null ? e.baton.model : e.baton.models;
+        matches: function (e) {
+            if (e.proceed) return;
+            if (e.collection.has('some', 'items') && !_.isEmpty(e.data)) {
+                var toCheck = e.models === null ? e.model : e.models;
                 if (util.hasEncrypted(toCheck)) {
                     e.stopPropagation();
                     return false;
@@ -131,16 +152,6 @@ define('oxguard/files/register', [
         }
     });
 
-    ext.point('io.ox/files/classic-toolbar/links').extend(new links.Link({
-        id: 'sendcopy',
-        index: 1200,
-        prio: 'lo',
-        mobile: 'lo',
-        label: gt('Send by mail'),
-        ref: 'oxguard/sendcopy',
-        section: 'share'
-    }));
-
     //////////////  Viewer
     /// Links
 
@@ -160,7 +171,7 @@ define('oxguard/files/register', [
             var file = files[0];
             if (isOGFile(file)) {
                 auth_core.authorize(file, undefined, true)
-                .then (function (auth) {
+                .then(function (auth) {
                     var file_options = { params: {
                         cryptoAction: 'Decrypt',
                         cryptoAuth: auth,
@@ -182,217 +193,179 @@ define('oxguard/files/register', [
                     def.resolve(baton);
                 }, def.reject);
                 return def;
-            } else {
-                return def.resolve();
             }
+            return def.resolve();
+
         }
     });
 
     ext.point('io.ox/core/viewer/actions/toolbar/popoutstandalone').extend({
         id: 'popoutstandalone_guardcheck',
         index: 1,
-        requires: function (e) {
-            if (e.collection.has('one')) {
-                if (e.baton.model.isEncrypted()) {
-                    e.stopPropagation();
-                    return false;
-                }
+        device: '!smartphone',
+        matches: function (baton) {
+            var model = baton.model;
+            return model.get('group') !== 'localFile' && !baton.context.standalone && model.isEncrypted();
+        },
+        action: function (baton) {
+            if (baton.model.isEncrypted()) {
+                actionsUtil.invoke('oxguard/popoutstandalone', baton);
+                baton.preventDefault();
             }
         }
     });
 
-    ext.point('io.ox/core/viewer/toolbar/links/drive').extend(new links.Link({
+    ext.point('io.ox/core/viewer/toolbar/links/drive').extend({
         id: 'GuardViewerEncrypt',
         index: 200,
-        label: gt('Encrypt'),
+        title: gt('Encrypt'),
         ref: 'oxguard/encrypt',
         mobile: 'lo'
-    }));
+    });
 
-    ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend(new links.Link({
+    ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend({
         id: 'GuardViewerRemEncrypt',
         index: 200,
-        label: gt('Remove encryption'),
+        title: gt('Remove encryption'),
         ref: 'oxguard/remencrypt',
+        prio: 'lo',
         mobile: 'lo'
-    }));
+    });
 
-    ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend(new links.Link({
+    ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend({
         id: 'GuardViewerDownload',
         index: 201,
-        label: gt('Download decrypted'),
+        title: gt('Download decrypted'),
         ref: 'oxguard/download',
         section: 'export',
         mobile: 'lo'
-    }));
+    });
 
-    ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend(new links.Link({
+    ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend({
         id: 'GuardViewerDownloadEncr',
         index: 202,
-        label: gt('Download encrypted'),
+        title: gt('Download encrypted'),
         ref: 'oxguard/downloadEncrypted',
         section: 'export',
         mobile: 'lo'
-    }));
-
-    ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend(new links.Link({
-        prio: 'hi',
-        mobile: 'lo',
-        label: gt('Pop out'),
-        icon: 'fa  fa-external-link-square',
-        ref: 'oxguard/popoutstandalone',
-        customize: function () {
-            this.addClass('viewer-toolbar-popoutstandalone')
-                .attr({
-                    tabindex: '1',
-                    title: gt('Pop out standalone viewer'),
-                    'aria-label': gt('Pop out standalone viewer')
-                });
-        }
-    }));
+    });
 
     // Versions
-    // View is removed from versions currently
-    /*ext.point('io.ox/files/versions/links/inline').extend(new links.Link({
+
+    ext.point('io.ox/files/versions/links/inline').extend({
         id: 'GuardView',
         index: 90,
-        label: gt('View'),
+        title: gt('View this version'),
         ref: 'oxguard/versionView'
-    }));
-    */
+    });
 
-    ext.point('io.ox/files/versions/links/inline').extend(new links.Link({
-        id: 'GuardOpen',
-        index: 100,
-        label: gt('Decrypt and open'),
-        ref: 'oxguard/open'
-    }));
-
-    ext.point('io.ox/files/versions/links/inline').extend(new links.Link({
+    ext.point('io.ox/files/versions/links/inline').extend({
         id: 'GuardDownload',
         index: 200,
-        label: gt('Download decrypted'),
+        title: gt('Download decrypted'),
         ref: 'oxguard/download'
-    }));
-
-    // Remove the loc portion of the name in version list
-    ext.point('io.ox/files/details/version').extend({
-        index: 1,
-        id: 'GuardVersion',
-        draw: function () {}
     });
 
     //// Actions
 
     // Upload new encrypted file
-    new links.Action('io.ox/files/actions/uploadEncrypt', {
-        capabilities: 'guard-drive',
-        requires: function (e) {
-            return e.baton.app.folder.getData().then(function (data) {
-                //hide for virtual folders (other files root, public files root)
-                var virtual = _.contains(['14', '15'], data.id);
-                //no new files in trash folders
-                return folderAPI.can('create', data) && !virtual && !folderAPI.is('trash', data) && !folderAPI.isExternalFileStorage(data);
-            });
+
+    function isTrash(baton) {
+        var folderId, model;
+        if (baton.app) {
+            folderId = baton.app.folder.get();
+        } else if (baton.folder_id !== undefined) {
+            folderId = baton.folder_id;
+        } else if (baton.data) {
+            folderId = baton.data.folder_id;
+        }
+        model = folderAPI.pool.getModel(folderId);
+        return model ? folderAPI.is('trash', model.toJSON()) : false;
+    }
+
+    // Upload new encrypted file
+    new actionsUtil.Action('io.ox/files/actions/uploadEncrypt', {
+        capabilities: 'guard-drive && !guest',
+        matches: function (baton) {
+            if (_(['14', '15']).contains(baton.folder_id)) return false;
+            if (isTrash(baton)) return false;
+            return true;
         },
         action: function (baton) {
             ensureSetup().then(function () {
-                baton.file_options = { 'params': { 'cryptoAction': 'Encrypt' }};
-                ext.point('io.ox/files/actions/upload').invoke('action', this, baton);
+                baton.file_options = { 'params': { 'cryptoAction': 'Encrypt' } };
+                actionsUtil.invoke('io.ox/files/actions/upload', baton);
             });
         }
     });
 
-    new links.Action('oxguard/downloadEncrypted', {
-        requires: function (e) {
-            if (e.baton.data) {
-                if (isOGFile(e.baton.data)) {
+    new actionsUtil.Action('oxguard/downloadEncrypted', {
+        matches: function (baton) {
+            if (baton.first()) {
+                if (isOGFile(baton.first())) {
                     return (true);
                 }
             }
             return false;
         },
-        multiple: function (list) {
-            list.map(function (file) {
+        action: function (baton) {
+            baton.array().map(function (file) {
                 // For encrypted, wipe the cryptoAuth and cryptoAction
                 if (file && file.params) {
                     file.params = {};
                 }
             });
-            ext.point('io.ox/files/actions/download').invoke('multiple', this, list);
+            actionsUtil.invoke('io.ox/files/actions/download', baton);
 
         }
     });
 
-    ext.point('io.ox/files/actions/open').replace({
-        id: 'default',
-        requires: function (e) {
-            if (e.collection.has('multiple')) return false;
-            if (e.baton.data) {
-                if (isOGFile(e.baton.data)) {
-                    return (false);
-                }
-            }
-            // 'description only' items
-            return ((e.baton.data.group !== 'localFile') && (!_.isEmpty(e.baton.data.filename) || e.baton.data.file_size > 0));
-        }
-    });
-
     // Disable publication of Guard files
     ext.point('io.ox/files/actions/getalink').extend({
         index: 10,
         id: 'guardCheck',
-        requires: function (e) {
-            if (isOGFile(e.baton.data)) {
-                e.stopPropagation();
+        matches: function (baton) {
+            if (isOGFile(baton.first())) {
+                baton.stopPropagation();
                 return false;
             }
         }
     });
 
-    ext.point('io.ox/files/actions/invite').extend({
-        capabilities: 'guard-drive',
-        index: 10,
-        id: 'guardCheck',
-        requires: function () {
-            return false;
-        },
-        action: function (baton) {
-            // If OG file, needs authentication to change invite permissions
-            if (isOGFile(baton.data)) {
-                if (baton.data && baton.data.validated) {
-                    baton.data.validated = false;
-                    return;  // already authorized
-                }
-                baton.stopPropagation();  // Terminate
-                var loc = this;
-                require(['oxguard/auth', 'io.ox/core/extPatterns/actions'], function (auth_core, actions) {
-                    auth_core.authorize(baton, gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
-                    .done(function () {
-                        if (baton.data) baton.data.validated = true;
-                        baton.resumePropagation();
-                        actions.invoke('io.ox/files/actions/invite', loc, baton);  // OK, authorized, call the extension again
-                    })
-                    .fail(function () {
-                        baton.stopPropagation();
-                        window.setTimeout(function () {
-                            baton.resumePropagation();
-                        }, 500);
+    ext.point('io.ox/files/actions/invite').replace('default', function (original) {
+        return {
+            action: function (baton) {
+                if (isOGFile(baton.first())) {
+                    require(['oxguard/auth'], function (auth_core) {
+                        var options = {
+                            optPrompt: gt('Please re-enter your %s password.', window.oxguarddata.productName),
+                            minSingleUse: true
+                        };
+                        auth_core.authorize(baton, options)
+                        .done(function () {
+                            original.action(baton);
+                        })
+                        .fail(function (e) {
+                            require(['io.ox/core/notifications'], function (notify) {
+                                notify.yell('error', e);
+                            });
+                        });
                     });
-                });
+                } else {
+                    original.action(baton);
+                }
             }
-        }
+        };
     });
 
     // Replacement popout for Guard
-    new links.Action('oxguard/popoutstandalone', {
-        requires: function (e) {
-            if (e.collection.has('one')) {
-                var currentApp = ox.ui.App.getCurrentApp().getName();
-                // detail is the target of popoutstandalone, no support for mail attachments
-                return (currentApp !== 'io.ox/files/detail' && e.baton.model.isEncrypted());
-            }
-            return false;
+    new actionsUtil.Action('oxguard/popoutstandalone', {
+        collection: 'one',
+        id: 'guardPopout',
+        matches: function (baton) {
+            var currentApp = ox.ui.App.getCurrentApp().getName();
+            // detail is the target of popoutstandalone, no support for mail attachments
+            return (currentApp !== 'io.ox/files/detail' && baton.model.isEncrypted());
         },
         action: function (e) {
             ox.launch('io.ox/files/detail/main').done(function () {
@@ -407,59 +380,62 @@ define('oxguard/files/register', [
     });
 
     // View link within versions
-    new links.Action('oxguard/versionView', {
-        requires: function (e) {
-            return (isOGFile(e.baton.data));
+    new actionsUtil.Action('oxguard/versionView', {
+        matches: function (baton) {
+            if (!baton.isViewer) { return false; }
+            return (isOGFile(baton.first()));
         },
-        multiple: function (list) {
-            viewFile (list);
+        action: function (baton) {
+            viewFile(baton);
         }
     });
 
-    new links.Action('oxguard/sendcopy', {
-        capabilities: 'guard-drive',
-        requires: function (e) {
+    new actionsUtil.Action('oxguard/sendcopy', {
+        capabilities: 'guard-drive && webmail',
+        collection: 'some',
+        matches: function (baton) {
             //all files must be encrypted
-            var toCheck = e.baton.models === null ? e.baton.model : e.baton.models;
-            return e.collection.has('some') && util.hasEncrypted(toCheck) && util.isNotAttachment(toCheck) && capabilities.has('webmail');
+            var toCheck = baton.models === null ? baton.model : baton.models;
+            return util.hasEncrypted(toCheck) && util.isNotAttachment(toCheck);
         },
-        multiple: function (list) {
-            list.map(function (file) {
-                if (file.source === 'guardDrive') window.oxguarddata.action = 'fileAttach';
-            });
-            ext.point('io.ox/files/actions/send').invoke('multiple', this, list);
+        action: function (baton) {
+            window.oxguarddata.action = 'fileAttach';
+            baton.proceed = true;
+            actionsUtil.invoke('io.ox/files/actions/send', baton);
         }
     });
 
-    function okToDecrypt (e, data) {
+    function okToDecrypt(baton, data) {
         var virtual = _.contains(['14', '15'], data.id);
-        return e.collection.has('some', 'modify', 'items') && util.encryptedOnly(e.baton.models) &&
+        return baton.collection.has('some', 'modify', 'items') && util.encryptedOnly(baton.models) &&
             folderAPI.can('create', data) && !virtual && !folderAPI.is('trash', data) &&
             !folderAPI.isExternalFileStorage(data);
     }
 
-    new links.Action('oxguard/remencrypt', {
+    new actionsUtil.Action('oxguard/remencrypt', {
         capabilities: 'guard-drive',
-        requires: function (e) {
+        collection: '!folders',
+        matches: function (baton) {
             //all files must be encrypted
-            if (e.collection.has('folders')) return false;
-            if (e.baton.app) {
-                return e.baton.app.folder.getData().then(function (data) {
-                    return okToDecrypt (e, data);
+            if (!anyOGFiles(baton.data)) return false;
+            if (baton.app) {
+                return baton.app.folder.getData().then(function (data) {
+                    return okToDecrypt(baton, data);
                 });
             }
-            var folderId = _.isArray(e.baton.data) ? e.baton.data[0].folder_id : e.baton.data.folder_id;
+            var folderId = baton.first().folder_id;
             if (folderId) {
                 return folderAPI.get(folderId).then(function (data) {
-                    return okToDecrypt (e, data);
+                    return okToDecrypt(baton, data);
                 });
             }
             return false;
         },
-        multiple: function (list, baton) {
+        action: function (baton) {
             ensureSetup().then(function () {
                 auth_core.authorize(baton).then(function (auth) {
                     var warnShares = false;
+                    var list = baton.array();
                     for (var file in list) {
                         if (list[file].object_permissions && list[file].object_permissions.length > 0) {
                             warnShares = true;
@@ -497,41 +473,39 @@ define('oxguard/files/register', [
         require(['io.ox/files/api'], function (fileApi) {
             fileApi.copy(list, list[0].folder_id, false)
             .then(function (e) {
-                if (e.length == list.length) {
+                if (e.length === list.length) {
                     for (var i in list) {
                         if (e[i].data) {
                             fileApi.remove([list[i]], true);
                         }
                     }
-                } else {
-                    if (_.isString(e)) {
-                        require (['io.ox/core/notifications'], function (notify) {
-                            notify.yell('error', e);
-                        });
-                    }
+                } else if (_.isString(e)) {
+                    require(['io.ox/core/notifications'], function (notify) {
+                        notify.yell('error', e);
+                    });
                 }
             });
         });
     }
 
-    new links.Action('oxguard/open', {
-        requires: function (e) {
-            if (e.baton.data) {
-                if (isOGFile(e.baton.data)) {
+    new actionsUtil.Action('oxguard/open', {
+        matches: function (baton) {
+            if (baton.data) {
+                if (isOGFile(baton.first())) {
                     return (true);
                 }
             }
             return (false);
         },
-        multiple: function (list) {
-            auth_core.authorize(list).then(function (auth) {
+        action: function (baton) {
+            auth_core.authorize(baton.data).then(function (auth) {
                 var params = {
                     'cryptoAction': 'Decrypt',
                     'cryptoAuth': auth,
                     'session': ox.session
                 };
-                require (['io.ox/files/api'], function (fileApi) {
-                    _(list).each(function (file) {
+                require(['io.ox/files/api'], function (fileApi) {
+                    _(baton.array()).each(function (file) {
                         window.open(fileApi.getUrl(file, 'open', { params: params }));
                     });
                 });
@@ -540,25 +514,32 @@ define('oxguard/files/register', [
         }
     });
 
-    new links.Action('oxguard/download', {
-        requires: function (e) {
-            if (_.device('ios')) return false;
-            var toCheck = e.baton.models === null ? e.baton.model : e.baton.models;
-            if (toCheck === undefined) return false;
-            return e.collection.has('some') && util.encryptedOnly(toCheck) && util.isNotAttachment(toCheck);
+    new actionsUtil.Action('oxguard/download', {
+        device: '!ios',
+        collection: 'some',
+        matches: function (baton) {
+            var toCheck = baton.models === null ? baton.model : baton.models;
+            if (toCheck === undefined) {  // Not a model in versions
+                if (baton.data) {
+                    return isOGFile(baton.first());
+                }
+                return false;
+            }
+            return util.encryptedOnly(toCheck) && util.isNotAttachment(toCheck);
         },
-        multiple: function (list) {
+        action: function (baton) {
+            var list = baton.array();
             auth_core.authorize(list).then(function (auth) {
-                for (var file in list) {
-                    list[file].filename = (list[file].filename ? list[file].filename.replace('.pgp', '') : '');
-                    list[file].params = {
+                list.map(function (file) {
+                    file.filename = (file.filename ? file.filename.replace('.pgp', '') : '');
+                    file.params = {
                         'cryptoAction': 'Decrypt',
                         'cryptoAuth': auth,
                         'session': ox.session
                     };
-                    list[file].cache = false;
-                }
-                ext.point('io.ox/files/actions/download').invoke('multiple', this, list);
+                    file.cache = false;
+                });
+                actionsUtil.invoke('io.ox/files/actions/downloadversion', baton);
                 metrics('guard', 'decrypt & download');
             });
         }
@@ -570,37 +551,77 @@ define('oxguard/files/register', [
     ext.point('io.ox/files/actions/viewer').extend({
         id: 'guardview',
         index: 1,
-        requires: function (e) {
-            var toCheck = e.baton.models === null ? e.baton.model : e.baton.models;
-            if (toCheck === undefined) return false;
-            return e.collection.has('some') && util.encryptedOnly(toCheck);
+        collection: 'some && items',
+        // matches: hasAnyEncryptedFile,
+        matches: function (baton) {
+            if (baton.isViewer) return false;
+            return hasAnyEncryptedFileInSelection(baton);
         },
         action: function (baton) {
-            if (isOGFile(baton.data)) {
-                viewFile(baton);
-                baton.preventDefault();
+            viewFile(baton);
+        }
+    });
+
+    ext.point('io.ox/files/actions/viewer/display-version').extend({
+        index: 1,
+        id: 'guardVersion',
+        matches: function (baton) {
+            if (hasAnyEncryptedFileInSelection(baton)) {
+                baton.stopPropagation();
             }
         }
     });
 
-    // Remove file decode parameters from file models once viewer closes
-    ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend({
-        id: 'guardCleanup',
-        index: 1,
-        draw: function (baton) {
-            baton.context.viewerEvents.listenTo(baton.context.viewerEvents, 'viewer:beforeclose', function () {
-                _.map(baton.context.collection.models, function (file) {
-                    file.set('file_options', {});
-                });
-            });
+    // fix for #58841 - Viewer: In a mixture of encrypted and unencrypted files, preview fails if started with an unencrypted file.
+    // approach to fulfill user expectation to not being prompted for a password when viewing a single, unencrypted file.
+    function hasAnyEncryptedFileInSelection(baton) {
+
+        var selection = baton.array();
+        var hasAny = false;
+
+        if (selection.length === 1) {
+            // portal provides selection only and no baton.all
+            hasAny = isOGFile(selection[0]);
+        } else {
+            // check selected files for multi selection
+            hasAny = selection.some(isOGFile);
         }
-    });
+
+        return hasAny;
+    }
+
+    // first approach to handle the follow-up story of #58841, after release of Guard 2.10.2 / App Suite 7.10.2
+    // another idea would be integrating or tighter coupling ad hoc decrytion into the  Viewer.
+    //
+    // function hasAnyEncryptedFile(baton) {
+    //
+    //     var selection = baton.array();
+    //     var hasAny = false;
+    //
+    //     if (selection.length === 1) {
+    //         if (baton.all) {
+    //             // check all file models in case of a single file selection.
+    //             hasAny = baton.all.some(function (model) {
+    //                 return isOGFile(model.toJSON());
+    //             });
+    //         } else {
+    //             // portal provides selection only and no baton.all
+    //             hasAny = isOGFile(selection[0]);
+    //         }
+    //     } else {
+    //         // check selected files for multi selection
+    //         hasAny = selection.some(isOGFile);
+    //     }
+    //
+    //     return hasAny;
+    // }
 
     // Handle viewing Guard file
-    function viewFile (baton) {
-        if (isOGFile (baton.data)) {
+    function viewFile(baton) {
+        // if (hasAnyEncryptedFile(baton)) {
+        if (hasAnyEncryptedFileInSelection(baton)) {
             auth_core.authorize(baton).then(function (auth) {
-                require (['oxguard/files/downloader'], function (downloader) {
+                require(['oxguard/files/downloader'], function (downloader) {
                     downloader.viewFile(baton, 'view', auth);
                 });
             });
@@ -627,7 +648,7 @@ define('oxguard/files/register', [
                         metrics('guard', 'dropfile upload & encrypt');
                         require(['io.ox/files/upload/main'], function (fileUpload) {
                             fileUpload.setWindowNode(app.getWindowNode());
-                            fileUpload.create.offer(files, { folder: app.folder.get(), 'params': { 'cryptoAction': 'Encrypt' }});
+                            fileUpload.create.offer(files, { folder: app.folder.get(), 'params': { 'cryptoAction': 'Encrypt' } });
                         });
                     });
                 }
@@ -642,7 +663,7 @@ define('oxguard/files/register', [
 
         if (!util.isGuardConfigured()) {
             var def = $.Deferred();
-            require (['oxguard/core/createKeys'], function (keys) {
+            require(['oxguard/core/createKeys'], function (keys) {
                 oxguard.metrics('drive', 'create-keys');
                 keys.createKeysWizard()
                 .then(def.resolve, def.reject);
@@ -655,32 +676,35 @@ define('oxguard/files/register', [
 
     ////////  Encrypting files
 
-    function okToEncrypt (e, data) {
+    function okToEncrypt(baton, data) {
         var virtual = _.contains(['14', '15'], data.id);
-        return e.collection.has('some', 'modify', 'items') && !util.encryptedOnly(e.baton.models) &&
+        return baton.collection.has('some', 'modify', 'items') && !util.encryptedOnly(baton.models) &&
             folderAPI.can('create', data) && !virtual && !folderAPI.is('trash', data) &&
             !folderAPI.isExternalFileStorage(data);
     }
 
-    new links.Action('oxguard/encrypt', {
+    new actionsUtil.Action('oxguard/encrypt', {
         capabilities: 'guard-drive',
-        requires: function (e) {
+        collection: 'some',
+        matches: function (baton) {
             //all files must be unencrypted
-            if (e.collection.has('folders')) return false;
-            if (e.baton.app) {
-                return e.baton.app.folder.getData().then(function (data) {
-                    return okToEncrypt (e, data);
+            if (baton.app) {
+                return baton.app.folder.getData().then(function (data) {
+                    if (allOGFiles(baton.data)) return false;
+                    return okToEncrypt(baton, data);
                 });
             }
-            var folderId = _.isArray(e.baton.data) ? e.baton.data[0].folder_id : e.baton.data.folder_id;
+            var folderId = _.isArray(baton.data) ? baton.data[0].folder_id : baton.data.folder_id;
             if (folderId) {
                 return folderAPI.get(folderId).then(function (data) {
-                    return okToEncrypt (e, data);
+                    if (allOGFiles(baton.data)) return false;
+                    return okToEncrypt(baton, data);
                 });
             }
             return false;
         },
-        multiple: function (list) {
+        action: function (baton) {
+            var list = _.isArray(baton.data) ? baton.data : [baton.data];
             ensureSetup().then(function () {
                 var warnShares = false;
                 for (var file in list) {
@@ -718,18 +742,16 @@ define('oxguard/files/register', [
         require(['io.ox/files/api'], function (fileApi) {
             fileApi.copy(list, list[0].folder_id, false)
             .then(function (e) {
-                if (e.length == list.length) {
+                if (e.length === list.length) {
                     for (var i in list) {
                         if (e[i].data) {
                             fileApi.remove([list[i]], true);
                         }
                     }
-                } else {
-                    if (_.isString(e)) {
-                        require (['io.ox/core/notifications'], function (notify) {
-                            notify.yell('error', e);
-                        });
-                    }
+                } else if (_.isString(e)) {
+                    require(['io.ox/core/notifications'], function (notify) {
+                        notify.yell('error', e);
+                    });
                 }
             });
         });
@@ -737,7 +759,7 @@ define('oxguard/files/register', [
 
     /////////////////  Util, prompts, etc
 
-    function metrics (target, action) {
+    function metrics(target, action) {
         require(['io.ox/metrics/main'], function (metrics) {
             if (!metrics.isEnabled()) return;
             metrics.trackEvent({
@@ -757,6 +779,27 @@ define('oxguard/files/register', [
     }
 
     */
+
+    // Checks if any of the files are encrypted
+    function anyOGFiles(_files) {
+        var files = _.isArray(_files) ? _files : [_files];
+        var any = false;
+        files.map(function (file) {
+            any = any || isOGFile(file);
+        });
+        return any;
+    }
+
+    // Checks if all files are Encrypted
+    function allOGFiles(_files) {
+        var files = _.isArray(_files) ? _files : [_files];
+        var all = true;
+        files.map(function (file) {
+            all = all && isOGFile(file);
+        });
+        return all;
+    }
+
     function isOGFile(file) {
         try {
             if (!file.filename) return (false);
