@@ -11,7 +11,7 @@ define('oxguard/files/util', [
             return list.reduce(function (acc, file) {
                 return acc && file.isEncrypted();
             }, true);
-        } else return (list.isEncrypted());
+        } return (list.isEncrypted());
     };
 
     util.hasEncrypted = function hasEncryptd(list) {
@@ -22,7 +22,7 @@ define('oxguard/files/util', [
                 if (file.isEncrypted()) encrypted = true;
             });
             return (encrypted);
-        } else return (list.isEncrypted());
+        } return (list.isEncrypted());
     };
 
     util.isNotAttachment = function isNotAttachment(list) {
@@ -31,7 +31,7 @@ define('oxguard/files/util', [
             return list.reduce(function (acc, file) {
                 return acc && (file.pgpFormat === undefined);
             }, true);
-        } else return (list.get('pgpFormat') === undefined);
+        } return (list.get('pgpFormat') === undefined);
     };
 
     return util;
