@@ -1,7 +1,8 @@
 define('oxguard/mail/maillist', [
     'io.ox/mail/common-extensions',
+    'io.ox/mail/api',
     'io.ox/core/extensions'
-], function (extensions, ext) {
+], function (extensions, mailApi, ext) {
     'use strict';
 
     var initialized = false;
@@ -17,14 +18,24 @@ define('oxguard/mail/maillist', [
         );
     };
 
+    extensions.pgp.signed = function (baton) {
+        //simple check for signed mail
+        if (!/^multipart\/signed/.test(baton.data.content_type) &&
+            !(baton.data.security && baton.data.security.signatures)) return;
+
+        this.append(
+            $('<i class="fa fa-pencil-square-o signed" aria-hidden="true">')
+        );
+    };
+
     // Changed selection.  Null out the guard current data
-    function change () {
+    function change() {
         window.oxguarddata.current = null;
     }
 
     // To initialize listview.  Setup here
     function listViewInit() {
-        require (['io.ox/mail/main'], function (main) {
+        require(['io.ox/mail/main'], function (main) {
             var app = main.getApp();
             if (app.listView !== undefined) {
                 app.listView.on('selection:change', change);
@@ -36,6 +47,20 @@ define('oxguard/mail/maillist', [
     ext.point('io.ox/mail/listview/item/default/row2').disable('paper-clip');
     ext.point('io.ox/mail/listview/item/small/col4').disable('paper-clip');
 
+    ext.point('io.ox/mail/listview/item').extend({
+        id: 'checkReload',
+        index: 10,
+        draw: function (baton) {
+            var pooledMail = mailApi.pool.get('detail').get(baton.data.cid);
+            if (pooledMail) {
+                if (pooledMail.get('guardIcons')) {  // PGP emails may have been already decrypted, etc
+                    baton.data.security = pooledMail.get('guardIcons').security;
+                    baton.data.attachment = pooledMail.get('guardIcons').attachment;
+                }
+            }
+        }
+    });
+
     ext.point('io.ox/mail/listview/item/default/row2').extend({
         id: 'OGpaper-clip',
         index: 300,
@@ -73,16 +98,7 @@ define('oxguard/mail/maillist', [
                     return;
                 }
             }
-            if (baton.model.get('content_type') === 'multipart/encrypted') {
-                return;
-            }
-            var headers = baton.model.get('headers');
-            if (headers === undefined) {
-                extensions.paperClip.call(this, baton);
-                return;
-            }
-            var attachments = baton.model.get('attachments');
-            if (attachments === undefined) {
+            if (/multipart\/encrypted/.test(baton.model.get('content_type'))) {
                 return;
             }
             /// PGP Components
