@@ -21,28 +21,26 @@ define('oxguard/mail/options_new', [
     var lockclass = 'icon-lock icon-2x fa fa-lock fa-2x oxguard_lock';
 
     function createlock(baton) {
-        baton.view.listenTo(baton.view.model, 'change:encrypt', function () {
+        baton.view.listenTo(baton.view.securityModel, 'change:encrypt', function () {
             setLock(baton);
         });
         setLock(baton);
     }
 
-    function setLock (baton) {
-        if (baton.model.get('encrypt')) {
+    function setLock(baton) {
+        if (baton.view.securityModel.get('encrypt')) {
             core.lock(baton);
         } else {
             core.unlock(baton);
         }
     }
 
-    function warnHTML (baton) {
-        var format = baton.model.get('PGPFormat');
-        if (format === 'inline' || format === 'mime') {  // If one is selected, turn on encryption
-            core.lock(baton);
-        }
-        if (format !== 'inline') return;
-        if (baton.model.get('editorMode') === 'text') return;
-        require (['io.ox/core/tk/dialogs'], function (dialogs) {
+    function warnHTML(baton) {
+        var format = baton.view.securityModel.get('PGPFormat');
+        var encrypt = baton.view.securityModel.get('encrypt');
+        if (format !== 'inline' || !encrypt) return;  // Don't display warning if not Inline or not encrypted
+        if (baton.config.get('editorMode') === 'text') return;
+        require(['io.ox/core/tk/dialogs'], function (dialogs) {
             var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true });
             dialog.header($('<h4>').text(gt('HTML Formatted Email')));
             var body = $('<p>');
@@ -52,9 +50,9 @@ define('oxguard/mail/options_new', [
             .addPrimaryButton('ok', gt('OK'), 'okx')
             .addButton('cancel', gt('Cancel'), 'cancel')
             .on('ok', function () {
-                baton.model.set('editorMode', 'text');
-                baton.model.on('change:editorMode', function () {
-                    if ((baton.model.get('editorMode') === 'html') && (baton.model.get('PGPFormat') === 'inline')) {
+                baton.config.set('editorMode', 'text');
+                baton.config.on('change:editorMode', function () {
+                    if ((baton.model.get('editorMode') === 'html') && (baton.view.securityModel.get('PGPFormat') === 'inline')) {
                         var dialog2 = new dialogs.CreateDialog({ width: 450, height: 300, center: true });
                         dialog2.header($('<h4>').text(gt('HTML Formatted Email')));
                         var warn = $('<p>').append(gt('HTML format is not recommended when using PGP Inline'));
@@ -73,7 +71,7 @@ define('oxguard/mail/options_new', [
         if (current === null || current === undefined) {  // if no decoded data, then return default
             if (settings.get('defaultInline')) {
                 return ('inline');
-            } else return ('mime');
+            } return ('mime');
         }
         if (current.pgpFormat === 'pgpmime') return ('mime');
         return ('inline');
@@ -89,110 +87,113 @@ define('oxguard/mail/options_new', [
             }, 1000);
         }
 
-        if (window.oxguarddata.action === 'sendfile') {// If it is going to be sending already encrypted file, then don't add encryption options
+        if (window.oxguarddata.action === 'sendfile') { // If it is going to be sending already encrypted file, then don't add encryption options
             window.oxguarddata.action = null;
             return;
         }
-        if (window.oxguarddata.sentfolder === undefined) {// Get sent folder data for sending
+        if (window.oxguarddata.sentfolder === undefined) { // Get sent folder data for sending
             require(['settings!io.ox/mail']).done(function (settings) {
                 window.oxguarddata.sentfolder = settings.get('folder/sent');
                 window.oxguarddata.draftfolder = settings.get('folder/drafts');
             });
         }
-        var mode = baton.model.get('mode');
-        ox.once('mail:' + mode + ':ready', function () {
-            baton.model.dirty(false);
-            // If this is a secure reply, then disable all of the options to make it plain text
-            if ((window.oxguarddata.action === 'secureReply') || (window.oxguarddata.action === 'fileAttach') || (util.hasEncryptedAttachment(baton) > 0)) {
-                if (window.oxguarddata.replyInline === true) {
-                    baton.model.set('PGPFormat', 'inline');
-                    window.oxguarddata.replyInline = null;
-                }
-                if (baton.model.get('PGPFormat') === undefined) { // If not previously defined
-                    baton.model.set('PGPFormat', getType(window.oxguarddata.current));
-                }
-                baton.model.set('encrypt', true);
-                if (window.oxguarddata.settings.oxguard === false || window.oxguarddata.settings.secureReply === true) {
-                    baton.view.$el.find('#statuslock')
-                        .attr('class', lockclass)
-                        .click(false)
-                        .attr('title', gt('Reply must be encrypted'));
-                    baton.view.$el.find('[data-name="encrypt"]').click(false);
-                }
-                window.oxguarddata.action = null;
+
+        var securityModel = baton.view.securityModel;
+
+        // If this is a secure reply, then disable all of the options to make it plain text
+        if ((window.oxguarddata.action === 'secureReply') || (window.oxguarddata.action === 'fileAttach') || (util.hasEncryptedAttachment(baton) > 0)) {
+            if (window.oxguarddata.replyInline === true) {
+                securityModel.setInline();
+                window.oxguarddata.replyInline = null;
             }
-            var headers = baton.model.get('headers');
-            if (headers && (headers['X-OxGuard-Sign'] === 'true')) {
-                baton.model.set('PGPSignature', true);
+            if (securityModel.get('PGPFormat') === undefined) { // If not previously defined
+                securityModel.set('PGPFormat', getType(window.oxguarddata.current));
             }
-        });
+            securityModel.set('encrypt', true);
+            if (window.oxguarddata.settings.oxguard === false || window.oxguarddata.settings.secureReply === true) {
+                baton.view.$el.find('#statuslock')
+                    .attr('class', lockclass)
+                    .click(false)
+                    .attr('title', gt('Reply must be encrypted'));
+                baton.view.$el.find('[data-name="encrypt"]').click(false);
+            }
+            window.oxguarddata.action = null;
+        }
+
+        var headers = baton.model.get('headers');
+        if (headers && (headers['X-OxGuard-Sign'] === 'true')) {
+            securityModel.set('PGPSignature', true);
+        }
 
         createlock(baton);
 
-        if (baton.model.get('newmail') === true && coreUtil.hasGuardMailCapability()) {  // New email doesn't have recips yet.  Check to see if there are defaults
+        if (baton.config.get('newmail') === true && coreUtil.hasGuardMailCapability()) {  // New email doesn't have recips yet.  Check to see if there are defaults
             // If default is to use guard, go ahead and lock
             if (settings.get('defaultEncrypted')) {
-                baton.model.set('encrypt', true);
+                securityModel.set('encrypt', true);
                 core.lock(baton);
-            } else baton.model.set('encrypt', false);
+            } else securityModel.set('encrypt', false);
             if (settings.get('defaultInline')) {
                 if (settings.get('defaultEncrypted')) {
-                    baton.model.set('PGPFormat', 'inline');
+                    securityModel.setInline();
                     warnHTML(baton);
                 } else {
-                    baton.model.set('PGPFormat', 'i');  // deactivated inline status
+                    securityModel.setInline();
                 }
-            } else baton.model.set('PGPFormat', 'mime');
-            baton.model.unset('newmail');
+            } else securityModel.setMime();
+            baton.config.unset('newmail');
 
             if (settings.get('defaultSign')) {
-                baton.model.set('PGPSignature', true);
+                securityModel.set('PGPSignature', true);
             }
         }
-        baton.model.on('change:PGPFormat', function () {
-            setSettings (baton.model);
+
+        securityModel.on('change:PGPFormat change:encrypt', function () {
             warnHTML(baton);
         });
-        baton.model.on('change:PGPSignature', function () {
-            setSettings (baton.model);
+
+        securityModel.on('change:PGPFormat', function () {
+            securityModel.set('encrypt', true);
         });
-        baton.model.on('change:PubKey', function () {
-            if (baton.model.get('PubKey')) {
-                attachPubKey (baton);
+
+        securityModel.on('change:PubKey', function () {
+            if (securityModel.get('PubKey')) {
+                attachPubKey(baton);
             }
         });
 
-        setSettings (baton.model);
-        return;
     }
-
-    function setSettings (model) {
-        var security = model.get('security');
-        security.pgpInline = (model.get('PGPFormat') === 'inline');
-        security.encrypt = model.get('encrypt');
-        security.sign = model.get('PGPSignature') ? true : false;
-        model.set('security', security);
-    }
-
     // Attach the users public key to the email
-    function attachPubKey (baton) {
+    function attachPubKey(baton) {
         var attachments = baton.model.get('attachments');
+        var securityModel = baton.view.securityModel;
         for (var i = 0; i < attachments.models.length; i++) {
             if (attachments.models[i].get('guard') === 'pubkey') {
-                baton.model.set('PubKey', false);
+                securityModel.set('PubKey', false);
                 return;
             }
         }
-        require(['oxguard/mail/pubkey', 'io.ox/core/notifications'], function (pk, notify) {
+        require(['oxguard/mail/pubkey', 'io.ox/core/notifications', 'io.ox/mail/compose/api'], function (pk, notify, composeApi) {
             pk.getPubKeyAttachment()
             .done(function (key) {
-                baton.model.attachFiles(key);
+                try {
+                    var file = new Blob([key.content], { type: 'application/pgp-keys' });
+                    file.name = key.filename;
+                    composeApi.space.attachments.add(baton.model.get('id'), { file: file })
+                    .then(function (data) {
+                        baton.model.attachFiles(data);
+                    });
+                } catch (e) {
+                    console.error(e);
+                    notify.yell('error', gt('Unable to attach your public key'));
+                }
+
             })
             .fail(function () {
                 notify.yell('error', gt('Unable to attach your public key'));
             })
             .always(function () {
-                baton.model.set('PubKey', false);
+                securityModel.set('PubKey', false);
             });
         });
     }
