@@ -19,16 +19,14 @@ define('oxguard/mail/oxguard_mail_password', [
 ], function (ext, oxguard, http, passwords, PasswordView, gt, guardSettings) {
     'use strict';
 
-    var encrPrivKey = '';
-
     ////////////////////////   RECEIVE / READ
 
     function loadKeyClick(evt) {
         var file = evt.target.files[0];
         var reader = new FileReader();
 
-        reader.onload = function (event) {
-            encrPrivKey = event.target.result;
+        reader.onload = function () {
+            //encrPrivKey = event.target.result;
             $('#privKeyButton').html(gt('Loaded'));
         };
         reader.readAsText(file);
@@ -39,7 +37,9 @@ define('oxguard/mail/oxguard_mail_password', [
         var id = decodeURIComponent(baton.data.id);
         try {
             id = id.substring(id.lastIndexOf('/') + 1) + (baton.view.cid ? baton.view.cid : '');
-        } catch (e) {}
+        } catch (e) {
+            console.error(e);
+        }
         return (id);
     }
 
@@ -136,20 +136,20 @@ define('oxguard/mail/oxguard_mail_password', [
                 duration = $('#duration' + id).val();
             }
             if (localOnly) {
-                goFunction (password, duration);
+                goFunction(password, duration);
                 return;
             }
             passwordbox.parent().busy();
             passButton.prop('disabled', true);
-            oxguard.savePassword (password, duration)
+            oxguard.savePassword(password, duration)
             .done(function () {
-                goFunction (password);
+                goFunction(password);
             })
             .fail(function (data) {
                 $('#busygif').hide();
                 passwordbox.parent().idle();
                 passButton.prop('disabled', false);
-                require (['io.ox/core/notifications'], function (notifications) {
+                require(['io.ox/core/notifications'], function (notifications) {
                     if (data.auth && data.auth.indexOf('Lockout') > -1) {
                         notifications.yell('error', gt('Temporary Lockout'));
                     } else {
