@@ -5,11 +5,12 @@ define('oxguard/mail/register_compose', [
     'oxguard/mail/oxguard_mail_compose_core',
     'oxguard/util',
     'pgp_mail/toggle-encryption',
-    'io.ox/backbone/mini-views/help',
+    'io.ox/backbone/mini-views/helplink',
     'oxguard/mail/keymanager',
     'settings!oxguard',
+    'oxguard/mail/security_model',
     'less!oxguard/mail/style'
-], function (ext, gt, Dropdown, core, util, ToggleEncryption, HelpView, keyman, settings) {
+], function (ext, gt, Dropdown, core, util, ToggleEncryption, HelpView, keyman, settings, SecurityModel) {
     'use strict';
 
     // Setup of compose
@@ -23,32 +24,34 @@ define('oxguard/mail/register_compose', [
                 return;
             }
             var node = this;
+            var securityModel = new SecurityModel(baton.model.get('security'), baton.model);
+            baton.view.securityModel = securityModel;
             var view = new ToggleEncryption.View({
-                model: baton.model
-            });
+                model: securityModel
+            }, baton.model);
             view.noLinkMail(baton.view);
             baton.view.toggleEncryption = view;
-
-            node.append(view.render().$el);
-            setupCompose (baton);
+            node.find('.sender').append(view.render().$el);
+            node.find('.mail-input').addClass('guardMail');
+            setupCompose(baton);
         }
     });
 
-    function setupCompose (baton) {
+    function setupCompose(baton) {
 
         // Check the options for the page.  Lock icon settings, etc
-        require (['oxguard/mail/options_new'], function (options) {
+        require(['oxguard/mail/options_new'], function (options) {
             options.createOptions(baton);
         });
     }
 
     // Check if attachment is PGP file, and set email to encrypt if found
-    function checkEncrAttachmentAdded (val, baton) {
+    function checkEncrAttachmentAdded(val, baton) {
         if ((val.get('file_mimetype') === 'application/pgp-enrypted') ||
                 (val.get('filename') && val.get('filename').indexOf('.pgp') > 0)) {
-            require (['io.ox/core/capabilities'], function (capabilities) {
+            require(['io.ox/core/capabilities'], function (capabilities) {
                 if (capabilities.has('guard-mail')) {
-                    baton.model.set('encrypt', true);
+                    baton.view.securityModel.set('encrypt', true);
                 }
             });
         }
@@ -60,7 +63,7 @@ define('oxguard/mail/register_compose', [
         index: 200,
         draw: function (baton) {
             baton.model.get('attachments').on('add', function (val) {
-                checkEncrAttachmentAdded (val, baton);
+                checkEncrAttachmentAdded(val, baton);
             });
         }
     });
@@ -70,7 +73,7 @@ define('oxguard/mail/register_compose', [
         index: 100,
         draw: function (baton) {
             var node = this;
-            drawDropDown (baton, $(node));
+            drawDropDown(baton, $(node));
         }
     });
 
@@ -79,10 +82,10 @@ define('oxguard/mail/register_compose', [
     ext.point('io.ox/mail/compose/createtoken').extend({
         id: 'guardToken',
         action: function (baton) {
-            if (baton.model.get('encrypt') === true) {
+            if (baton.view.securityModel.get('encrypt') === true) {
                 var email = baton.event.attrs.model.get('token').value;
                 var target = $(baton.event.relatedTarget);
-                keyman.checkRecips (email, baton)
+                keyman.checkRecips(email, baton)
                 .done(function (keyResults) {
                     core.drawKeyIcons(keyResults[email], target);
                 });
@@ -94,10 +97,10 @@ define('oxguard/mail/register_compose', [
     ext.point('io.ox/mail/compose/removetoken').extend({
         id: 'guardDelToken',
         action: function (baton) {
-            if (baton.model.get('gkeys')) {
+            if (baton.config.get('gkeys')) {
                 var email = baton.event.attrs.model.get('token').value;
                 require(['oxguard/mail/keymanager'], function (keyman) {
-                    keyman.deleteRecip (email, baton);
+                    keyman.deleteRecip(email, baton);
                 });
             }
         }
@@ -105,105 +108,116 @@ define('oxguard/mail/register_compose', [
 
     // Send extension points
 
-    ext.point('io.ox/mail/compose/actions/send').extend({
-        id: 'signCheck',
-        index: 610,
-        perform: function (baton) {
-            var def = $.Deferred();
-            var security = baton.model.get('security');
-            if (security.sign) {
-                require(['oxguard/auth'], function (auth) {
-                    auth.authorize(baton, gt('Please enter your %s password to sign this email.', window.oxguarddata.productName), true)
-                    .done(function (auth) {
-                        var security = baton.model.get('security');
-                        security.authentication = auth;
-                        baton.model.set('security', security);
-                        if (baton.model.get('security').encrypt) {
-                            checkKeys(baton, def);
-                        } else {
-                            def.resolve();
-                        }
-                    })
-                    .fail(function () {
-                        baton.stopPropagation();
-                        def.reject();
+    ext.point('io.ox/mail/compose/actions/send').extend(
+        {
+            // Check if all keys have been checked
+            id: 'keysDoneCheck',
+            index: 100,
+            before: 'busy:start',
+            perform: function (baton) {
+                if (!baton.view.securityModel.get('encrypt')) return true;
+                var def = $.Deferred();
+                if (isReady(baton)) {
+                    def.resolve();
+                } else {
+                    waitUntilReady(baton, def);
+                }
+                return (def);
+            }
+        },
+        {
+            // Check if password needed for signing
+            id: 'signCheck',
+            index: 200,
+            before: 'busy:start',
+            perform: function (baton) {
+                var def = $.Deferred();
+                var security = baton.model.get('security');
+                if (security.sign) {
+                    require(['oxguard/auth'], function (auth) {
+                        var options = {
+                            optPrompt: gt('Please enter your %s password to sign this email.', window.oxguarddata.productName),
+                            minSingleUse: true
+                        };
+                        auth.authorize(baton, options)
+                        .done(function (auth) {
+                            var security = baton.model.get('security');
+                            security.authentication = auth;
+                            baton.model.set('security', security);
+                            if (baton.model.get('security').encrypt) {
+                                checkKeys(baton, def);
+                            } else {
+                                def.resolve();
+                            }
+                        })
+                        .fail(function () {
+                            baton.stopPropagation();
+                            def.reject();
+                        });
                     });
-                });
-            } else {
-                if (security.encrypt) {
+                } else if (security.encrypt) {
                     checkKeys(baton, def);
                 } else {
                     def.resolve();
                 }
+                return (def);
             }
-            return (def);
-        }
-    });
-
-    // Checks to see if any encrypted attachments and if auth is preset
-    ext.point('io.ox/mail/compose/actions/send').extend({
-        id: 'encryptedFiles',
-        index: 620,
-        perform: function (baton) {
-            if (!baton.model.get('encrypt')) return true;
-            var security = baton.model.get('security');
-            var def = $.Deferred();
-            var attachments = baton.model.get('attachments');
-            var found = false;
-            attachments.models.forEach(function (attach) {
-                if (found) return;  // Only prompt once
-                var mimeType = attach.get('file_mimetype');
-                var fileName = attach.get('filename');
-                if ((mimeType && (mimeType.indexOf('pgp-encrypted') > -1)) || (fileName && (fileName.indexOf('.pgp') > -1))) {
-                    found = true;
-                    require(['oxguard/auth'], function (auth) {
-                        auth.authorize(baton, gt('There appears to be an encrypted attachment.  Please enter your %s password to decode the attachment for sending.', window.oxguarddata.productName), true)
-                        .done(function (auth) {
-                            security.authentication = auth;
-                            baton.model.set('security', security);
-                            def.resolve();
-                        })
-                        .fail(function () {
-                            def.reject();
+        },
+        {
+            // Check if encrypted files attached that need password for decryption
+            id: 'encryptedFiles',
+            index: 300,
+            before: 'busy:start',
+            perform: function (baton) {
+                if (!baton.view.securityModel.get('encrypt')) return true;
+                var security = baton.model.get('security');
+                var def = $.Deferred();
+                var attachments = baton.model.get('attachments');
+                var found = false;
+                attachments.models.forEach(function (attach) {
+                    if (found) return;  // Only prompt once
+                    var mimeType = attach.get('file_mimetype');
+                    var fileName = attach.get('filename');
+                    if ((mimeType && (mimeType.indexOf('pgp-encrypted') > -1)) || (fileName && (fileName.indexOf('.pgp') > -1))) {
+                        found = true;
+                        require(['oxguard/auth'], function (auth) {
+                            var options = {
+                                optPrompt: gt('There appears to be an encrypted attachment.  Please enter your %s password to decode the attachment for sending.', window.oxguarddata.productName),
+                                minSingleUse: true
+                            };
+                            auth.authorize(baton, options)
+                            .done(function (auth) {
+                                security.authentication = auth;
+                                baton.model.set('security', security);
+                                def.resolve();
+                            })
+                            .fail(function () {
+                                def.reject();
+                            });
                         });
-                    });
-                }
-            });
-            if (!found) def.resolve();
-            return (def);
-        }
-    });
-
-    // Check that all keys have been found prior to sending
-    ext.point('io.ox/mail/compose/actions/send').extend({
-        id: 'keysDoneCheck',
-        index: 601,
-        perform: function (baton) {
-            if (!baton.model.get('encrypt')) return true;
-            var def = $.Deferred();
-            if (isReady(baton)) {
-                def.resolve();
-            } else {
-                waitUntilReady(baton, def);
-            }
-            return (def);
-        }
-    });
-
-    ext.point('io.ox/mail/compose/actions/send').extend({
-        id: 'checkAuthErrors',
-        index: 1100,
-        perform: function (baton) {
-            if (baton.result && containsError(baton.result.code, baton.result.error)) {
-                handleFail(baton);
-                handleReauth (gt('Please re-enter your %s password before sending.', window.oxguarddata.productName), baton)
-                .done(function () {
-                    baton.view.send();
+                    }
                 });
-                return new $.Deferred().reject();
+                if (!found) def.resolve();
+                return (def);
+            }
+        },
+        {
+            // Check for authentication errors
+            id: 'checkAuthErrors',
+            index: 100,
+            after: 'send',
+            perform: function (baton) {
+                if (baton.result && containsError(baton.result.code, baton.result.error)) {
+                    handleFail(baton);
+                    handleReauth(gt('Please re-enter your %s password before sending.', window.oxguarddata.productName), baton)
+                    .done(function () {
+                        baton.view.send();
+                    });
+                    return new $.Deferred().reject();
+                }
             }
         }
-    });
+    );
 
     // Save extension points
 
@@ -213,7 +227,7 @@ define('oxguard/mail/register_compose', [
         perform: function (baton) {
             if (baton.result && containsError(baton.result.code, baton.result.error)) {
                 handleFail(baton);
-                handleReauth (gt('Please re-enter your %s password before saving.', window.oxguarddata.productName), baton)
+                handleReauth(gt('Please re-enter your %s password before saving.', window.oxguarddata.productName), baton)
                 .done(function () {
                     baton.view.saveDraft();
                 });
@@ -232,10 +246,15 @@ define('oxguard/mail/register_compose', [
             if (containsError(baton.code, baton.error)) {
                 baton.preventDefault();
                 if (reauthorizing) return;
-                var reauthorizing = true,
-                security = baton.model.get('security');
+                reauthorizing = true;
+                var security = baton.model.get('security');
                 require(['oxguard/auth'], function (auth) {
-                    auth.authorize(baton, gt('Please re-enter your %s password.', window.oxguarddata.productName), true, true)
+                    var options = {
+                        optPrompt: gt('Please re-enter your %s password.', window.oxguarddata.productName),
+                        minSingleUse: true,
+                        forceRelogin: true
+                    };
+                    auth.authorize(baton, options)
                     .done(function (auth) {
                         if (security) {  // Update security authorization
                             security.authentication = auth;
@@ -256,10 +275,10 @@ define('oxguard/mail/register_compose', [
     // Functions
 
     // Drawing dropdown options for security
-    function drawDropDown (baton, node) {
+    function drawDropDown(baton, node) {
         if (window.oxguarddata && window.oxguarddata.settings) {
             if (window.oxguarddata.settings.oxguard) {
-                var dropdown = new Dropdown({ model: baton.model, label: gt('Security'), caret: true });
+                var dropdown = new Dropdown({ model: baton.view.securityModel, label: gt('Security'), caret: true });
                 if (settings.get('advanced')) {
                     dropdown
                         .header(gt('PGP'));
@@ -272,7 +291,7 @@ define('oxguard/mail/register_compose', [
                     .option('PGPSignature', true, gt('Sign'));
                 if (settings.get('advanced')) {
                     dropdown
-                  //#. Format of the email, HTML or Plaintext
+                    //#. Format of the email, HTML or Plaintext
                     .header(gt('Format'))
                     .option('PGPFormat', 'mime', gt('PGP Mime'))
                     .option('PGPFormat', 'inline', gt('PGP Inline'));
@@ -299,8 +318,8 @@ define('oxguard/mail/register_compose', [
     }
 
     // Check if any of the recipients are Guest and prompt for greeting/password
-    function checkKeys (baton, def) {
-        var keys = baton.model.get('gkeys');
+    function checkKeys(baton, def) {
+        var keys = baton.config.get('gkeys');
         var isGuest = false;
         var fail = false;
         for (var email in keys) {
@@ -308,7 +327,7 @@ define('oxguard/mail/register_compose', [
             if (keys[email].result === 'fail') fail = true;
         }
         if (fail) {
-            require (['io.ox/core/notifications'], function (notifications) {
+            require(['io.ox/core/notifications'], function (notifications) {
                 notifications.yell('error', gt('Unable to find keys for all recipients.'));
             });
             baton.stopPropagation();
@@ -319,7 +338,7 @@ define('oxguard/mail/register_compose', [
             def.resolve();
             return;
         }
-        require (['oxguard/mail/guestPrompt'], function (prompt) {
+        require(['oxguard/mail/guestPrompt'], function (prompt) {
             prompt.guestOptions(baton)
             .done(function (data) {
                 var security = _.extend(baton.model.get('security'), data);
@@ -334,8 +353,8 @@ define('oxguard/mail/register_compose', [
     }
 
     // Check all keys ready
-    function isReady (baton) {
-        var keys = baton.model.get('gkeys');
+    function isReady(baton) {
+        var keys = baton.config.get('gkeys');
         if (keys === undefined) return true; // No keys
         var pending = false;
         for (var email in keys) {
@@ -345,7 +364,7 @@ define('oxguard/mail/register_compose', [
     }
 
     // Check if response code and error string contain auth error
-    function containsError (code, string) {
+    function containsError(code, string) {
         if (code === 'GRD-MW-0001') return true;  // Midleware Auth error
         if (code !== 'GUARD-0003') return false;
         return (string && string !== null &&
@@ -374,7 +393,12 @@ define('oxguard/mail/register_compose', [
         var def = $.Deferred();
         require(['oxguard/auth'], function (auth) {
             var security = baton.model.get('security');
-            auth.authorize(baton, prompt, true, true)  // authorize and force relogin
+            var options = {
+                optPrompt: prompt,
+                minSingleUse: true,
+                forceRelogin: true
+            };
+            auth.authorize(baton, options)  // authorize and force relogin
             .done(function (auth) {
                 security.authentication = auth;
                 baton.model.set('security', security);
@@ -391,7 +415,7 @@ define('oxguard/mail/register_compose', [
 
     // If not all keys returned, wait until completed.
     // Timeout if no backend response
-    function waitUntilReady (baton, def) {
+    function waitUntilReady(baton, def) {
         baton.waiting = true;
         var win = baton.view.app.getWindow();
         win.busy();
