@@ -21,13 +21,13 @@ define('oxguard/oxguard_core', [
     //// Utils
 
     function validateEmail(email) {
-        var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
+        var re = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
         return re.test(email);
     }
 
     // Unified inbox combines folder and email ID, returns email id
 
-    function metrics (app, action) {
+    function metrics(app, action) {
         require(['io.ox/metrics/main'], function (metrics) {
             if (!metrics.isEnabled()) return;
             metrics.trackEvent({
@@ -39,14 +39,31 @@ define('oxguard/oxguard_core', [
         });
     }
 
-    function sanitize (data) {
+    function sanitize(data) {
         var regex = new RegExp('<(?:!--(?:(?:-*[^->])*--+|-?)|script\\b(?:[^"\'>]|"[^"]*"|\'[^\']*\')*>[\\s\\S]*?</script\\s*|style\\b(?:[^"\'>]|"[^"]*"|\'[^\']*\')*>[\\s\\S]*?</style\\s*|/?[a-z](?:[^"\'>]|"[^"]*"|\'[^\']*\')*)>', 'gi');
         return (data.replace(regex, ''));
     }
 
+    // Escape html data to prevent cross scripting attack
+    function htmlSafe(data) {
+        var xss = {
+            '&': '&amp;',
+            '<': '&lt;',
+            '>': '&gt;',
+            '"': '&quot;',
+            "'": '&#39;',
+            '/': '&#x2F;',
+            '`': '&#x60;',
+            '=': '&#x3D;'
+        };
+        return String(data).replace(/[&<>"'`=/]/g, function (s) {
+            return xss[s];
+        });
+    }
+
     //// Failure Handling
 
-    function handleJsonError (error, errorResponse, baton) {
+    function handleJsonError(error, errorResponse, baton) {
         errorResponse.errorMessage = gt('Error');
         errorResponse.retry = false;
         if (error.code !== undefined) {
@@ -58,7 +75,7 @@ define('oxguard/oxguard_core', [
                         return;
                     }
                     errorResponse.errorMessage = gt('Unable to decrypt Email, incorrect password.');
-                    require (['io.ox/core/notifications'], function (notifications) {
+                    require(['io.ox/core/notifications'], function (notifications) {
                         notifications.yell('error', gt('Bad password'));
                     });
                     badCount++;
@@ -76,20 +93,20 @@ define('oxguard/oxguard_core', [
         }
     }
 
-    function showError (errorJson) {
+    function showError(errorJson) {
         var errorResp = {};
         try {
-            handleJsonError (errorJson, errorResp);
+            handleJsonError(errorJson, errorResp);
         } catch (e) {
             errorResp.errorMessage = gt('Unspecified error');
         }
-        require (['io.ox/core/notifications'], function (notifications) {
+        require(['io.ox/core/notifications'], function (notifications) {
             notifications.yell('error', errorResp.errorMessage);
         });
 
     }
 
-    function checkJsonOK (json) {
+    function checkJsonOK(json) {
         if (json && json.error) {
             showError(json);
             return false;
@@ -100,10 +117,10 @@ define('oxguard/oxguard_core', [
     /// Authentication Section
 
     // Password prompt
-    function getpassword (message, timeOption) {
+    function getpassword(message, timeOption, options) {
         var def = $.Deferred();
         require(['oxguard/core/passwordPrompt'], function (prompt) {
-            prompt.open(message, timeOption)
+            prompt.open(message, timeOption, options)
             .done(function (data) {
                 def.resolve(data);
             })
@@ -115,7 +132,7 @@ define('oxguard/oxguard_core', [
     }
 
     // Save existing authentication token to OX Session
-    function saveAuthToSession (auth, time) {
+    function saveAuthToSession(auth, time) {
         var def = $.Deferred();
         var url = ox.apiRoot + '/guard-json?action=auth-token';
         var params = '';
@@ -127,8 +144,8 @@ define('oxguard/oxguard_core', [
         if (time !== undefined) {
             authToken.minutesValid = time;
         }
-        og_http.put (url, params, authToken)
-        .done (function (data) {
+        og_http.put(url, params, authToken)
+        .done(function (data) {
             def.resolve(data.auth);
         })
         .fail(function () {
@@ -144,27 +161,27 @@ define('oxguard/oxguard_core', [
     }
 
     // Save a password in both auth code and token
-    function savePassword (password, duration) {
+    function savePassword(password, duration) {
         var def = $.Deferred();
         if (duration > 9999) duration = 0;  // 0 for session
-        authAndSave (password, duration)
+        authAndSave(password, duration)
         .done(function (data) {
             def.resolve(data.data);
-            storeAuth (data.data.auth, duration);
+            storeAuth(data.data.auth, duration);
         })
         .fail(function (e) {
             def.reject(e);
-            require (['io.ox/core/notifications'], function (notify) {
+            require(['io.ox/core/notifications'], function (notify) {
                 switch (e.code) {
-                case 'GRD-MW-0003':
-                    notify.yell('error', gt('Bad password'));
-                    break;
-                case 'GRD-MW-0005':
-                    notify.yell('error', gt('Account locked out due to bad attempts.  Please try again later.'));
-                    break;
-                default:
-                    notify.yell('error', gt('Error checking password') + '\r\n' + e.error);
-                    break;
+                    case 'GRD-MW-0003':
+                        notify.yell('error', gt('Bad password'));
+                        break;
+                    case 'GRD-MW-0005':
+                        notify.yell('error', gt('Account locked out due to bad attempts.  Please try again later.'));
+                        break;
+                    default:
+                        notify.yell('error', gt('Error checking password') + '\r\n' + e.error);
+                        break;
                 }
                 console.error(e);
             });
@@ -173,7 +190,7 @@ define('oxguard/oxguard_core', [
     }
 
     // Store the auth locally for a time
-    function storeAuth (auth, duration) {
+    function storeAuth(auth, duration) {
         if (duration >= 0) {
             window.oxguarddata.passcode = auth;
             var time = duration * 1000 * 60;
@@ -186,11 +203,15 @@ define('oxguard/oxguard_core', [
     }
 
     // Check if authentication token in session and valid
-    function checkAuth () {
+    function checkAuth(o) {
+        var preAuthDone;
+        if (window.oxguarddata.passcode && window.oxguarddata.passcode.length > 20) {  // stored auth code
+            preAuthDone = preAuthCallback(o);
+        }
         var def = $.Deferred();
         var url = ox.apiRoot + '/guard-json?action=auth-token';
-        og_http.get (url, '')
-        .done (function (data) {
+        og_http.get(url, '')
+        .done(function (data) {
             if (data.data === undefined) {
                 def.reject('none');
                 return;
@@ -199,25 +220,29 @@ define('oxguard/oxguard_core', [
             if (data.minutesValid !== undefined) {
                 if (data.minutesValid >= -1) { // -1 is single use
                     if (data.minutesValid >= 0) { // If more than single use, store locally
-                        storeAuth (data.auth, data.minutesValid);
+                        storeAuth(data.auth, data.minutesValid);
                     }
                     def.resolve(data); // OK only if exists and still time left.
+                    if (!preAuthDone) preAuthCallback(o);
+                    callback(o, data.auth);
                     return;
-                } else {
-                    window.oxguarddata.passcode = null;
                 }
+                window.oxguarddata.passcode = null;
+
             }
             def.reject('exp');
+            if (preAuthDone) failAuthCallback(o);
         })
-        .fail (function (e) {
+        .fail(function (e) {
             console.log(e);
             def.reject('fail');
+            if (preAuthDone) failAuthCallback(o);
         });
         return def;
     }
 
     // Send password for authentication and save it to session
-    function authAndSave (password, duration) {
+    function authAndSave(password, duration) {
         var def = $.Deferred();
         var userdata = {
             password: password,
@@ -226,14 +251,14 @@ define('oxguard/oxguard_core', [
         var url = ox.apiRoot + '/guard-json?action=auth-token';
         var params = '&time=' + new Date().getTime();
         og_http.post(url, params, userdata)
-        .done (function (data) {
+        .done(function (data) {
             if (data.error) {
                 def.reject(data);
                 return;
             }
             def.resolve(data);
         })
-        .fail (function (e) {
+        .fail(function (e) {
             def.reject(e);
         });
         return def;
@@ -241,8 +266,7 @@ define('oxguard/oxguard_core', [
     }
 
     // Authenticate against the Guard server, checking for specific key ID, return settings info
-    function authorize(userid, password, extra, keyid)
-    {
+    function authorize(userid, password, extra, keyid) {
         var def = $.Deferred();
         userAPI.get().then(function (userData) {
             var defaultSendAddress = $.trim(settings.get('defaultSendAddress', ''));
@@ -251,11 +275,14 @@ define('oxguard/oxguard_core', [
                 lang: ox.language,
                 email: defaultSendAddress ? defaultSendAddress : userData.email1
             };
+            if (!userdata.email || userdata.email.length < 1) {
+                def.reject();
+            }
             var url = ox.apiRoot + '/oxguard/login?action=login';
             var params = '&time=' + new Date().getTime();
             if (keyid !== undefined) params += '&keyid=' + keyid;
-            og_http.post (url, params, userdata)
-            .done (function (data) {
+            og_http.post(url, params, userdata)
+            .done(function (data) {
                 def.resolve(data);
             })
             .fail(function () {
@@ -265,16 +292,41 @@ define('oxguard/oxguard_core', [
         return def;
     }
 
-    function hasLocalKeys () {
+    function hasLocalKeys() {
         return (guardSettings.get('localKeys') && guardSettings.get('pgplocal'));
     }
 
+    function autoCryptEnabled() {
+        return (window.oxguarddata && window.oxguarddata.settings && window.oxguarddata.settings.autoCryptEnabled);
+    }
+
+    function preAuthCallback(o) {
+        if (o && _.isFunction(o.preAuthCallback)) {
+            o.preAuthCallback();
+            return true;
+        }
+        return false;
+    }
+
+    function callback(o, auth) {
+        if (o && _.isFunction(o.callback)) {
+            o.callback(auth);
+        }
+    }
+
+    function failAuthCallback(o) {
+        if (o && _.isFunction(o.failAuthCallback)) {
+            o.failAuthCallback();
+        }
+    }
+
     return {
         auth: authorize,
         validateEmail: validateEmail,
         getPassword: getpassword,
         showError: showError,
         sanitize: sanitize,
+        htmlSafe: htmlSafe,
         checkJsonOK: checkJsonOK,
         saveAuthToSession: saveAuthToSession,
         checkAuth: checkAuth,
@@ -282,7 +334,8 @@ define('oxguard/oxguard_core', [
         removeAuth: removeAuth,
         metrics: metrics,
         storeAuth: storeAuth,
-        hasLocalKeys: hasLocalKeys
+        hasLocalKeys: hasLocalKeys,
+        autoCryptEnabled: autoCryptEnabled
     };
 });
 
