@@ -8,8 +8,7 @@
  */
 define('oxguard/pgp/register', [
     'io.ox/core/extensions',
-    'io.ox/core/extPatterns/links',
-    'io.ox/core/extPatterns/actions',
+    'io.ox/backbone/views/actions/util',
     'oxguard/core/og_http',
     'oxguard/mail/checker',
     'io.ox/core/api/account',
@@ -17,11 +16,12 @@ define('oxguard/pgp/register', [
     'pgp_mail/util',
     'oxguard/mail/mail_metrics',
     'io.ox/mail/common-extensions',
+    'oxguard/auth',
     'settings!oxguard',
     'gettext!oxguard',
     'oxguard/mail/mailReplyActions',
     'less!oxguard/pgp/style'
-], function (ext, links, actions, http, checker, account, capabilities, util, metrics, mailExtensions, settings, gt) {
+], function (ext, actionsUtil, http, checker, account, capabilities, util, metrics, mailExtensions, auth_core, settings, gt) {
     'use strict';
 
     // Draw security icons in mail detail view
@@ -44,18 +44,15 @@ define('oxguard/pgp/register', [
             var signedicon;
             if (sig.verified) {
                 signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa guard_signed" aria-hidden="true" title="' + gt('This Email was signed and verified.') + '"/>');
-            } else {
-                if (!sig.missing) {
-                    var display = gt('This Email was signed and failed verification.');
-                    if (sig.error) {
-                        display += ' ' + sig.error;
-                    }
-                    signedicon = $('<i class="oxguard_icon_fa_alert fa-pencil-square fa guard_signed" aria-hidden="true" title="' + display + '"/>');
-                }
+            } else if (!sig.missing) {
+                signedicon = $('<i class="oxguard_icon_fa_error fa-pencil-square fa guard_signed" aria-hidden="true" title="' + gt('This Email was signed and failed verification.') + '"/>');
             }
             if (sig.missing) {
                 signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa guard_signed" style="color:lightgrey" aria-hidden="true" title="' + gt('This Email was signed but unable to verify.') + '"/>');
             }
+            if (sig.error) {
+                signedicon = $('<i class="oxguard_icon_fa_error fa-pencil-square fa guard_signed" aria-hidden="true" title="' + gt('Error verifying signature: %s', sig.error) + '"/>');
+            }
             if (_.device('small')) {
                 signedicon.css('margin-right', '10px');
             }
@@ -64,7 +61,7 @@ define('oxguard/pgp/register', [
         checkIntegrity(baton.data);
     };
 
-    function checkIntegrity (data) {
+    function checkIntegrity(data) {
         if (data && data.headers) {
             if (data.headers['X-Guard-Failed-Integrity']) {
                 require(['io.ox/core/notifications'], function (notify) {
@@ -74,9 +71,37 @@ define('oxguard/pgp/register', [
         }
     }
 
+    ext.point('io.ox/mail/detail/header').extend({
+        id: 'guardNotices',
+        index: 'last',
+        draw: function (baton) {
+            if (settings.get('suppressInfo')) {
+                return;
+            }
+            var security = baton.model.get('security');
+            if (security) {
+                var warn;
+                var div = $('<div class="oxguard_info">');
+                if (security && security.signatures) {
+                    var sig = security.signatures[0];
+                    if (sig && sig.missing) {
+                        div.append($('<span>').append(gt('Unable to verify signature.  Missing public key.')));
+                        warn = true;
+                    }
+                    if (sig && !sig.verified && !sig.missing && !sig.error) {
+                        div.append($('<span class="signError">').append(gt('This Email was signed and failed verification.')));
+                        warn = true;
+                    }
+                }
+                if (warn) this.append(div);
+            }
+
+        }
+    });
+
     // Detail View Extensions
     ext.point('io.ox/mail/detail/body').extend({
-        id:'guardCheck',
+        id: 'guardCheck',
         index: 1,
         draw: function (baton) {
             if (baton.data.PGP) {  // If drawing a PGP email, and already decoded
@@ -112,10 +137,21 @@ define('oxguard/pgp/register', [
             }
             if (baton.data.security_info && baton.data.security_info.encrypted) {
                 baton.stopPropagation();
+                checkAutocryptHeaders(baton);  // Check headers for the encrypted emails
             }
         }
     });
 
+    // Check for autocrypt header
+    ext.point('io.ox/mail/detail/body').extend({
+        requires: 'guard-mail',
+        index: 1000,
+        id: 'autocrypt',
+        draw: function (baton) {
+            checkAutocryptHeaders(baton);
+        }
+    });
+
     ext.point('io.ox/mail/mobile/detail/body').extend({
         index: 230,
         id: 'ogPGPCheckMobile',
@@ -169,7 +205,7 @@ define('oxguard/pgp/register', [
 
     // Methods for actions
     // Check if attachment filename ends with .asc
-    function isASC (e) {
+    function isASC(e) {
         try {
             if (e.context instanceof Array) {
                 for (var i = 0; i < e.context.length; i++) {
@@ -190,16 +226,39 @@ define('oxguard/pgp/register', [
         }
     }
 
-    // test a single file if it is a key
-    function testKey (file) {
-        var test = {
-                collection: null,
-                context: file
-            };
-        return (isKey (test));
+    function checkAutocryptHeaders(baton) {
+        if (baton.model && baton.model.get('headers')) {
+            var headers = baton.model.get('headers');
+            if (headers.Autocrypt || headers['Autocrypt-Gossip']) {
+                require(['oxguard/pgp/autocrypt/autoCrypt'], function (autocrypt) {
+                    if (headers.Autocrypt) {
+                        autocrypt.check(baton.model)
+                        .done(function () {
+                            if (!settings.get('advanced')) return;  // Only users with advanced settings would have verified key
+                            if (baton.data.security_info && baton.data.security_info.signed) {  //If signed, pull again after import
+                                checker.pullAgain(false, baton);
+                            }
+                        });
+                    }
+                    if (headers['Autocrypt-Gossip']) {
+                        autocrypt.checkGossip(baton.model);
+                    }
+
+                });
+            }
+        }
     }
 
-    function isKey (e) {
+    // test a single file if it is a key
+    function testKey(file) {
+        var test = {
+            collection: null,
+            context: file
+        };
+        return (isKey(test));
+    }
+
+    function isKey(e) {
         if (isASC(e)) {
             if (e.collection === null || e.collection.has('one')) { // only return true for individual files
                 var type;
@@ -218,7 +277,12 @@ define('oxguard/pgp/register', [
                 return (/[0x]*[0-9A-F]{8}\.asc/i).test(name); // Regex for 8 hex.asc
             }
         }
-        return false ;
+        return false;
+    }
+
+    function testAutoCrypt(file) {
+        if (file && file.content_type === 'application/autocrypt-setup') return true;
+        return false;
     }
 
     ext.point('io.ox/mail/detail/attachments').extend({
@@ -226,10 +290,14 @@ define('oxguard/pgp/register', [
         draw: function (e) {
             if (capabilities.has('guest')) return;
             var keyfound = false;
+            var autoCryptStart = false;
             e.attachments.forEach(function (a) {
                 if (testKey(a)) {
                     keyfound = true;
                 }
+                if (testAutoCrypt(a)) {
+                    autoCryptStart = true;
+                }
             });
             if (keyfound) {
                 var keydiv = $('<div class="importKey">');
@@ -239,54 +307,56 @@ define('oxguard/pgp/register', [
                 });
                 this.append(keydiv.append(notice));
             }
+            if (autoCryptStart) {
+                var aCkeydiv = $('<div class="importKey">');
+                var aCnotice = $('<span>' + gt('AutoCrypt startup found.  Click to import key') + '</span>');
+                aCnotice.click(function () {
+                    require(['oxguard/pgp/autocrypt/autoCrypt'], function (autoCrypt) {
+                        autoCrypt.doStart(e.attachments);
+                    });
+                });
+                this.append(aCkeydiv.append(aCnotice));
+            }
         }
     });
 
-    new links.Action('io.ox/mail/actions/save-encrypted-attachment', {
+    new actionsUtil.Action('io.ox/mail/actions/save-encrypted-attachment', {
         capabilities: 'infostore guard-drive',
-        requires: function (e) {
-            if (!e.collection.has('some')) {
-                return false;
-            }
-            return (util.isDecrypted(e.baton.data));
+        matches: function (baton) {
+            return util.isDecrypted(baton.first());
         },
-        multiple: function (list) {
-            require(['oxguard/auth', 'io.ox/mail/actions/attachmentSave'], function (auth_core, action) {
-                auth_core.authorize(list, gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
+        collection: 'some',
+        action: function (baton) {
+            require(['io.ox/mail/actions/attachmentSave'], function (action) {
+                var options = {
+                    optPrompt: gt('Please re-enter your %s password.', window.oxguarddata.productName),
+                    minSingleUse: true
+                };
+                auth_core.authorize(baton.data, options)
                 .done(function () {
+                    var list =
+                         _.isArray(baton.data) ? baton.data : [baton.data];
                     for (var i = 0; i < list.length; i++) {
                         list[i].reEncrypt = true;
                     }
-                    action.multiple (list);
+                    action.multiple(list);
                 });
             });
         }
     });
 
-    ext.point('io.ox/mail/attachment/links').extend(
-        new links.Link({
-            id: 'saveEncrypted',
-            index: 550,
-            mobile: 'high',
-            // #. %1$s is usually "Drive" (product name; might be
-            // customized)
-            label: gt('Save encrypted to %1$s', gt.pgettext('app',
-                    'Drive')),
-            ref: 'io.ox/mail/actions/save-encrypted-attachment'
-        }));
-
-    new links.Action('io.ox/mail/actions/PGPPublicKey', {
-        id: 'PGPKey',
-        requires: function (e) {
-            return isKey(e);
-        },
-        multiple: function (list) {
-            metrics.track('import-pgp-public-key');
-            doImportKey (list);
-        }
+    ext.point('io.ox/mail/attachment/links').extend({
+        id: 'saveEncrypted',
+        index: 550,
+        mobile: 'high',
+        // #. %1$s is usually "Drive" (product name; might be
+        // customized)
+        title: gt('Save encrypted to %1$s', gt.pgettext('app',
+            'Drive')),
+        ref: 'io.ox/mail/actions/save-encrypted-attachment'
     });
 
-    function doImportKey (list) {
+    function doImportKey(list) {
         if (window.oxguarddata.passcode === 'No Key') {
             require(['oxguard/core/createKeys'], function (keys) {
                 metrics.track('create-keys-to-import-public');
@@ -302,24 +372,25 @@ define('oxguard/pgp/register', [
 
     /// Sent folder extensions
 
-    ext.point('io.ox/mail/links/inline').extend(new links.Link({
+    ext.point('io.ox/mail/links/inline').extend({
         index: 101,
         prio: 'lo',
         id: 'pinlink',
-        label: gt('Check assigned PIN'),
+        title: gt('Check assigned PIN'),
         ref: 'io.ox/mail/actions/pin',
         mobile: 'lo'
-    }));
+    });
 
     var unified_sent = '';
 
-    new links.Action('io.ox/mail/actions/pin', {
+    new actionsUtil.Action('io.ox/mail/actions/pin', {
         id: 'statusaction',
-        requires: function (e) {
-            if (!(_.contains(account.getFoldersByType('sent'), e.context.folder_id)) && (e.context.folder_id !== unified_sent)) return (false);
+        matches: function (baton) {
+            var e = baton.first();
+            if (!(_.contains(account.getFoldersByType('sent'), e.folder_id)) && (e.folder_id !== unified_sent)) return (false);
             try {
-                if (e.baton.data.headers === undefined) return (false);
-                return (e.baton.data.headers['X-OxGuard-PIN'] !== undefined);
+                if (e.headers === undefined) return (false);
+                return (e.headers['X-OxGuard-PIN'] !== undefined);
             } catch (ex) {
                 console.log(ex);
                 return (false);
@@ -330,11 +401,11 @@ define('oxguard/pgp/register', [
         }
     });
 
-    function pin (baton) {
-        require (['io.ox/core/tk/dialogs'], function (dialogs) {
+    function pin(baton) {
+        require(['io.ox/core/tk/dialogs'], function (dialogs) {
             var dialog = new dialogs.ModalDialog({ width: 300, center: true, enter: 'ok' });
             dialog.header($('<h4>').text(gt('PIN')));
-            var pin = baton.data.headers['X-OxGuard-PIN'];
+            var pin = baton.first().headers['X-OxGuard-PIN'];
             var pintext = $('<h2>').append(pin);
             dialog.getBody().append(pintext);
             dialog.addPrimaryButton('ok', gt('OK'), 'ok').show();
@@ -364,13 +435,15 @@ define('oxguard/pgp/register', [
         perform: function (baton) {
             var def = $.Deferred();
             if (baton.data.security && baton.data.security.decrypted) {
-                require(['oxguard/auth'], function (auth_core) {
-                    auth_core.authorize(baton, gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
-                    .done(function () {
-                        def.resolve();
-                    })
-                    .fail(def.reject);
-                });
+                var options = {
+                    optPrompt: gt('Please re-enter your %s password.', window.oxguarddata.productName),
+                    minSingleUse: true
+                };
+                auth_core.authorize(baton, options)
+                .done(function () {
+                    def.resolve();
+                })
+                .fail(def.reject);
             } else {
                 def.resolve();
             }
@@ -388,25 +461,19 @@ define('oxguard/pgp/register', [
 
     // Function to do authentication validation before calling an extension.
     // Checks if valid.  If not, prompts for password, calls extension again once auth
-    var validated = false;
-    function doAuthCheck(extName, baton, array, storeAuth) {
-        if (validated) {  // If already validated, return so that extension propagates
-            validated = false;
-            return;
-        }
+    function doAuthCheck(original, baton, storeAuth, minSingleUse) {
         baton.stopPropagation(); // Stop this extension and check authorization
 
         // Local decryption check.  If we decrypted locally, we will have decrypted sessionKey
         if (baton.data &&
                 (baton.data[0] && baton.data[0].security && baton.data[0].security.sessionKey) ||
                 (baton.data.security && baton.data.security.sessionKey)) {
-            require (['pgp_local/sessionHandler'], function (handler) {
+            require(['pgp_local/sessionHandler'], function (handler) {
                 var key = _.isArray(baton.data) ? baton.data[0].security.sessionKey : baton.data.security.sessionKey;
                 handler.saveDecryptedSession(key)
                 .done(function () {
-                    validated = true;
                     baton.resumePropagation();
-                    actions.invoke(extName, array, baton);  // OK, authorized, call the extension again
+                    original.action(baton);  // OK, authorized, call the extension again
                 })
                 .fail(function () {
                     window.setTimeout(function () {
@@ -418,33 +485,46 @@ define('oxguard/pgp/register', [
         }
 
         // Not local, so authorize against backend
-        require(['oxguard/auth', 'io.ox/core/extPatterns/actions'], function (auth_core, actions) {
-            auth_core.authorize(baton, gt('Please re-enter your %s password.', window.oxguarddata.productName), true)
-            .done(function (authData) {
-                if (baton.data) {
-                    if (_.isArray(baton.data)) {
-                        baton.data.forEach(function (d) {
-                            d.auth = authData;
-                        });
-                    } else {
-                        baton.data.auth = authData;
-                    }
+        var callback = function (authData) {
+            if (baton.data) {
+                if (_.isArray(baton.data)) {
+                    baton.data.forEach(function (d) {
+                        d.auth = authData;
+                    });
+                } else {
+                    baton.data.auth = authData;
                 }
+            }
+            baton.resumePropagation();
+            if (storeAuth) {
+                if (_.isArray(baton.data)) {
+                    baton.data.forEach(function (d) {
+                        d.security = _.extend({ authentication: authData }, d.security);
+                    });
+                } else {
+                    baton.first().security = _.extend({ authentication: authData }, baton.first().security);
+                }
+                // Guard-199, direct select of attachment adds list array
+                if (baton.list && _.isArray(baton.list)) {
+                    baton.list.forEach(function (d) {
+                        d.auth = authData;
+                        d.security = _.extend({ authentication: authData }, d.security);
+                    });
+                }
+            }
+            original.action(baton);
+        };
+        var options = {
+            optPrompt: gt('Please re-enter your %s password.', window.oxguarddata.productName),
+            minSingleUse: minSingleUse !== false,
+            callback: callback
+        };
+        auth_core.authorize(baton, options)
+        .fail(function () {
+            baton.stopPropagation();
+            window.setTimeout(function () {
                 baton.resumePropagation();
-                validated = true;
-                if (storeAuth) {
-                    if (baton.data) {
-                        baton.data.security = _.extend({ authentication: authData }, baton.data.security);
-                    }
-                }
-                actions.invoke(extName, array, baton);  // OK, authorized, call the extension again
-            })
-            .fail(function () {
-                baton.stopPropagation();
-                window.setTimeout(function () {
-                    baton.resumePropagation();
-                }, 500);
-            });
+            }, 500);
         });
     }
 
@@ -452,37 +532,36 @@ define('oxguard/pgp/register', [
     registerPasswordCheck('io.ox/mail/actions/reply-all', true);
     registerPasswordCheck('io.ox/mail/actions/forward', true);
     registerPasswordCheck('io.ox/mail/actions/edit', true);
+    registerPasswordCheck('io.ox/mail/actions/edit-copy', true);
     registerPasswordCheck('io.ox/mail/actions/print');
-    registerPasswordCheck('io.ox/mail/actions/view-attachment');
-    registerPasswordCheck('io.ox/mail/actions/open-attachment');
-    registerPasswordCheck('io.ox/mail/actions/download-attachment');
-    registerPasswordCheck('io.ox/mail/actions/save-attachment');
-    registerPasswordCheck('io.ox/mail/office/text-edit-asnew');
-    registerPasswordCheck('io.ox/mail/office/spreadsheet-edit-asnew');
-    registerPasswordCheck('io.ox/mail/actions/vcard');
-    registerPasswordCheck('io.ox/mail/actions/ical');
+    registerPasswordCheck('io.ox/mail/attachment/actions/view', true, 'default', false);
+    registerPasswordCheck('io.ox/mail/attachment/actions/open');
+    registerPasswordCheck('io.ox/mail/attachment/actions/download');
+    registerPasswordCheck('io.ox/mail/attachment/actions/save');
+    registerPasswordCheck('io.ox/mail/attachment/actions/vcard');
+    registerPasswordCheck('io.ox/mail/attachment/actions/ical');
 
     // Function to check actions for Guard emails, and if found, proper authentication
-    function registerPasswordCheck (extName, storeAuth) {
-        ext.point(extName).extend({
-            id: 'guardPasswordCheck',
-            index: 1,
-            requires: function () {
-                return false;  // Always false, depend on other requires to return true
-            },
-            multiple: function (array, baton) {
-                if (storeAuth) {
-                    if (util.isEncryptedMail(baton.data)) {
-                        baton.data.security = {
-                            decrypted: true
-                        };
-                        doAuthCheck(extName, baton, array, storeAuth);
+    function registerPasswordCheck(extName, storeAuth, id, minSingleUse) {
+        ext.point(extName).replace((id ? id : 'default'), function (original) {
+            return {
+                action: function (baton) {
+                    if (storeAuth) {
+                        if (util.isEncryptedMail(baton.first())) {
+                            baton.first().security = {
+                                decrypted: true
+                            };
+                            doAuthCheck(original, baton, storeAuth, minSingleUse);
+                            return;
+                        }
+                    }
+                    if (!util.isDecrypted(baton.first())) {
+                        original.action(baton);
                         return;
                     }
+                    doAuthCheck(original, baton, storeAuth, minSingleUse);
                 }
-                if (!util.isDecrypted(baton.data)) return;
-                doAuthCheck(extName, baton, array, storeAuth);
-            }
+            };
         });
     }
 
@@ -490,18 +569,18 @@ define('oxguard/pgp/register', [
      * Extension to check if allowed to forward decrypted/encrypted email
      * Must have Guard-mail capability
      */
-    ext.point('io.ox/mail/actions/forward').extend ({
+    ext.point('io.ox/mail/actions/forward').extend({
         id: 'guardLimitedReply',
         index: 10,
-        requires: function (e) {
-            if (e.baton) {
-                if (util.isDecrypted(e.baton.data) || util.isEncryptedMail(e.baton.data)) {
+        matches: function (baton) {
+            if (baton && baton.first()) {
+                if (util.isDecrypted(baton.first()) || util.isEncryptedMail(baton.first())) {
                     if (!capabilities.has('guard-mail')) {
-                        e.stopPropagation();
-                        return false;
+                        baton.stopPropagation();
                     }
                 }
             }
+            return false;
         }
     });
 
@@ -509,7 +588,7 @@ define('oxguard/pgp/register', [
     /// Functions
 
     // Save public key from attachment
-    function loadPublicKey (list) {
+    function loadPublicKey(list) {
         _(list).each(function (data) {
             if (testKey(data)) { // make sure key
                 var params = '&emailid=' + data.parent.id +
@@ -523,28 +602,32 @@ define('oxguard/pgp/register', [
                             params = params + '&auth=' + encodeURIComponent(auth) +
                             '&inline=' + (data.security.pgpInline ? 'true' : 'false') +
                             '&filename=' + encodeURIComponent(data.filename);
-                            doLoadPublicKey (params);
+                            doLoadPublicKey(params);
                         });
                     });
                 } else {
-                    doLoadPublicKey (params);
+                    doLoadPublicKey(params);
                 }
 
             }
         });
     }
 
-    function doLoadPublicKey (params) {
+    function doLoadPublicKey(params) {
         var link = ox.apiRoot + '/oxguard/pgpmail/?action=savepublicattach' + params;
         http.get(link, '')
         .done(function (data) {
-            require(['io.ox/core/notifications'], function (notify) {
-                var keys = JSON.parse(data);
+            require(['io.ox/core/notifications', 'oxguard/pgp/keyDetails'], function (notify, keydetails) {
+                var keys = data.data.externalPublicKeyRings;
                 var added = gt('Added keys: \r\n');
                 for (var i = 0; i < keys.length; i++) {
-                    added = added + gt('Key ID: ') + keys[i].Key + ' ' + keys[i].ids + '\r\n';
+                    added = added + gt('Key ID: ') + keys[i].ids + '\r\n';
+                    if (keys[i].publicRing && keys[i].publicRing.keys) {
+                        var details = keydetails.keyDetail(keys[i].publicRing.keys);
+                        added = added + gt('User IDs: ') + details.keyids;
+                    }
                 }
-                notify.yell('success', added.replace(/&lt;/g,'<').replace(/&gt;/g,'>'));
+                notify.yell('success', added.replace(/&lt;/g, '<').replace(/&gt;/g, '>'));
             });
         })
         .fail(function (e) {
@@ -552,9 +635,12 @@ define('oxguard/pgp/register', [
             require(['io.ox/core/notifications'], function (notify) {
                 if (e.status === 503) {
                     notify.yell('error', gt('Service Unavailable'));
-                } else
-                    notify.yell('error', e.responseText);
+                } else { notify.yell('error', e.responseText); }
             });
         });
     }
+
+    return {
+        registerPasswordCheck: registerPasswordCheck
+    };
 });
