@@ -23,8 +23,7 @@ define('oxguard/pgp/uploadkeys', [
                 deferred.reject();
                 return deferred;
             }
-            if (files[l] !== undefined)
-                formData.append('key' + l, files[l]);
+            if (files[l] !== undefined) { formData.append('key' + l, files[l]); }
         }
         if (priv) {
             formData.append('keyPassword', pgp);
@@ -61,11 +60,11 @@ define('oxguard/pgp/uploadkeys', [
                                 } else {
                                     var publicKeys = key.publicRing.keys;
                                     added = added + gt('Public keys: ');
-                                    for (var p = 0; p < publicKeys.length; p++) {
-                                        var pKey = publicKeys[p];
-                                        added = added + pKey.fingerPrint + '\r\n';
-                                        for (var d = 0; d < pKey.userIds.length; d++) {
-                                            added = added + pKey.userIds[d] + ' ';
+                                    for (var k = 0; k < publicKeys.length; k++) {
+                                        var pubKey = publicKeys[k];
+                                        added = added + pubKey.fingerPrint + '\r\n';
+                                        for (var j = 0; j < pubKey.userIds.length; j++) {
+                                            added = added + pubKey.userIds[j] + ' ';
                                         }
                                         added = added + '\r\n';
                                     }
@@ -106,8 +105,8 @@ define('oxguard/pgp/uploadkeys', [
     }
 
     // Verify ascii data contains key before upload
-    function validateKeyData (key) {
-        if (!/(-----BEGIN PGP PRIVATE KEY BLOCK-----|-----BEGIN PGP PUBLIC KEY BLOCK-----)[\d\w\r\n:\. +\/=]+(-----END PGP PRIVATE KEY BLOCK-----|-----END PGP PUBLIC KEY BLOCK-----)/i.test(key)) {
+    function validateKeyData(key) {
+        if (!/(-----BEGIN PGP PRIVATE KEY BLOCK-----|-----BEGIN PGP PUBLIC KEY BLOCK-----)[\d\w\r\n:. +/=]+(-----END PGP PRIVATE KEY BLOCK-----|-----END PGP PUBLIC KEY BLOCK-----)/i.test(key)) {
             notify.yell('error', gt('Does not appear to be a valid key file type'));
             return false;
         }
@@ -115,7 +114,7 @@ define('oxguard/pgp/uploadkeys', [
     }
 
     // Upload ascii key data
-    function uploadPublicKey (key) {
+    function uploadPublicKey(key) {
         var deferred = $.Deferred();
         if (!validateKeyData(key)) {
             deferred.reject();
@@ -184,7 +183,6 @@ define('oxguard/pgp/uploadkeys', [
                 if (core.checkJsonOK(data)) {
                     deferred.resolve('ok');
                 } else {
-                    notify.yell('error', gt('Error uploading key'));
                     deferred.reject();
                 }
                 uploading = false;
@@ -199,7 +197,7 @@ define('oxguard/pgp/uploadkeys', [
         return (deferred);
     }
 
-    function validFileType (file) {
+    function validFileType(file) {
         if (!/^.*\.(txt|pgp|gpg|asc)$/i.test(file.name)) {
             console.error('bad file type ' + file.name);
             notify.yell('error', gt('Does not appear to be a valid key file type'));
@@ -208,7 +206,7 @@ define('oxguard/pgp/uploadkeys', [
         return true;
     }
 
-    function createPasswordPrompt (files, def) {
+    function createPasswordPrompt(files, def) {
         return new ModalView({
             async: true,
             point: 'oxguard/pgp/uploadKeysPasswordPrompt',
@@ -242,18 +240,18 @@ define('oxguard/pgp/uploadkeys', [
     }
 
     ext.point('oxguard/pgp/uploadKeysPasswordPrompt').extend(
-            {
-                index: 100,
-                id: 'passwordPrompts',
-                render: function () {
+        {
+            index: 100,
+            id: 'passwordPrompts',
+            render: function () {
 
-                    this.$body.append(
-                        createPrompts()
-                    );
-                }
-            });
+                this.$body.append(
+                    createPrompts()
+                );
+            }
+        });
 
-    function createPrompts () {
+    function createPrompts() {
         var explain = $('<div><p>' + gt('Please enter passwords for the upload') + '</p>');
         var passdiv = $('<div>').addClass('row-fluid');
         var newogpassword = new PasswordView.view({ 'id': 'guardpassword', 'class': 'password_prompt', 'validate': true }).getProtected();
@@ -271,14 +269,14 @@ define('oxguard/pgp/uploadkeys', [
         .append($('<tr>').append('<td>').append(hint));
         var errormessage = $('<span id="uploaderror" style="color:red;"></span>');
         passdiv.append(table);
-        require (['oxguard/core/passwords'], function (pass) {
+        require(['oxguard/core/passwords'], function (pass) {
             pass.passwordCheck(newogpassword, hint);
             pass.passwordCompare(newogpassword2, newogpassword, hint);
         });
         return explain.append(passdiv).append(errormessage);
     }
 
-    function doUploadPrivate (files) {
+    function doUploadPrivate(files) {
         var deferred = $.Deferred();
         var pgp = $('#pgppassword').val();
         var guard = $('#guardpassword').val();
@@ -292,25 +290,23 @@ define('oxguard/pgp/uploadkeys', [
                 deferred.reject(gt('New password must be at least %s characters long', window.oxguarddata.settings.min_password_length));
                 return deferred;
             }
-        } else {
-            if (guard.trim().length < 2) { // If no min defined, make sure at least 2 characters there
-                uploadPrivate (files);
-                return deferred;
-            }
+        } else if (guard.trim().length < 2) { // If no min defined, make sure at least 2 characters there
+            uploadPrivate(files);
+            return deferred;
         }
-        upload (files, true, pgp, guard)
+        upload(files, true, pgp, guard)
         .done(function () {
             deferred.resolve('OK');
         })
         .fail(function (e) {
             console.log(e);
             deferred.reject(e ? e.trim() : '');
-            handleFail (e, notify);
+            handleFail(e, notify);
         });
         return deferred;
     }
 
-    function uploadPrivate (files) {
+    function uploadPrivate(files) {
         var deferred = $.Deferred();
         for (var i = 0; i < files.length; i++) {
             if (!validFileType(files[i])) {
@@ -322,7 +318,7 @@ define('oxguard/pgp/uploadkeys', [
         return deferred;
     }
 
-    function handleFail (e, notify) {
+    function handleFail(e, notify) {
         if (e === 'duplicate') {
             notify.yell('error', gt('This key already exists'));
             return;
