@@ -10,7 +10,7 @@ define('oxguard/portal/register', [
         index: 1000000,
         preview: function () {
             var content = $(this).find('.list-unstyled');
-            setupGuard (content);
+            setupGuard(content);
         }
     });
 
@@ -19,16 +19,16 @@ define('oxguard/portal/register', [
         index: 1000000,
         preview: function () {
             var content = $(this).find('.list-unstyled');
-            setupGuard (content);
+            setupGuard(content);
         }
     });
 
-    function setupGuard (content) {
+    function setupGuard(content) {
         content.unbind('click');
         content.on('click', 'li.item', function (e) {
             e.stopPropagation();
             var item = $(e.currentTarget).data('item');
-            if (isEncrypted (item)) {
+            if (isEncrypted(item)) {
                 require(['oxguard/files/register', 'io.ox/files/api'], function (files, filesAPI) {
                     var items = $(e.delegateTarget).data('items');
                     filesAPI.get(item).done(function (data) {
@@ -54,11 +54,11 @@ define('oxguard/portal/register', [
         });
     }
 
-    function isEncrypted (item) {
-        if (item.meta !== undefined) {
+    function isEncrypted(item) {
+        if (item.meta) {
             if (item.meta.Encrypted === true) return (true);
         }
-        if (item.filename !== undefined) {
+        if (item.filename) {
             if (item.filename.indexOf('.pgp') > 0) return (true);
         }
         return (false);
