@@ -10,20 +10,33 @@
 define('oxguard/settings', [
     'io.ox/core/extensions',
     'oxguard/util',
-    'io.ox/core/capabilities',
-    'gettext!oxguard'
-], function (ext, util, capabilities, gt) {
+    'io.ox/core/capabilities'
+], function (ext, util, capabilities) {
     'use strict';
 
     if (util.isGuardConfigured() || capabilities.has('guard-mail') || capabilities.has('guard-drive')) {
         // Add settings for encryption to the Settings Page
-        ext.point('io.ox/settings/pane/main').extend({
+        ext.point('io.ox/settings/pane/general/security').extend({
             id: 'oxguard',
             //#. %s product Name
-            title: gt.format(gt.pgettext('app', '%s Security'), window.oxguarddata.productName),
+            title: window.oxguarddata.productName,
             index: 600,
             loadSettingPane: true
         });
+
+        ext.point('io.ox/settings/help/mapping').extend({
+            id: 'guardHelp',
+            index: 200,
+            list: function () {
+                _.extend(this, {
+                    'virtual/settings/oxguard': {
+                        base: 'help',
+                        target: 'ox.appsuite.user.sect.guard.settings.html'
+                    }
+                });
+            }
+        });
+
     }
 
     if (!util.isGuardLoaded()) {
@@ -34,4 +47,5 @@ define('oxguard/settings', [
         };
         util.addOnLoaded(removeIfNotNeeded);
     }
+
 });
