@@ -2,11 +2,12 @@ define('oxguard/settings/defaults', [
 ], function () {
     'use strict';
 
-    function getDefault () {
+    function getDefault() {
         return undefined;
     }
 
     return {
-        cryptoProvider: getDefault()
+        cryptoProvider: getDefault(),
+        enableAutocrypt: true
     };
 });
