@@ -39,13 +39,13 @@ define('oxguard/settings/pane', [
 
     var INDEX = 0;
 
-    function drawGuardSettings (node, baton) {
+    function drawGuardSettings(node, baton) {
         guardUtil.hasSetupDone()
         .done(function () {
             node.empty();
             node.addClass('guard-settings');
             node.append(
-                    new ExtensibleView({ point: 'oxguard/settings/detail/view', model: settings })
+                new ExtensibleView({ point: 'oxguard/settings/detail/view', model: settings })
                     .inject({
                         getPasswordOptions: function () {
                             return ([
@@ -72,9 +72,9 @@ define('oxguard/settings/pane', [
                         });
                     })
                     .render().$el
-                );
+            );
         })
-        .fail (function () {
+        .fail(function () {
             require(['io.ox/core/capabilities'], function (capabilities) {
                 if (capabilities.has('guard-mail') || capabilities.has('guard-drive')) {
                     node.append(setupGuard(node, baton));
@@ -85,69 +85,70 @@ define('oxguard/settings/pane', [
     }
 
     ext.point('oxguard/settings/detail/view').extend(
-            {
-                id: 'header',
-                index: INDEX += 100,
-                render: function () {
-                    this.$el.addClass('io-ox-guard-settings').append(
-                        util.header(gt('%s security settings', window.oxguarddata.productName))
-                    );
-                }
-            },
-            {
-                id: 'defaults',
-                index: INDEX += 100,
-                render: function () {
-                    if (guardUtil.isGuest() || !guardUtil.hasGuardMailCapability()) return;   // Guests don't set defaults for sending
-                    this.$el.append(
-                        $('<div class="guardDefaults">').append(
-                            util.fieldset(
-                                gt('Defaults'),
-                                // default to encrypt outgoing
-                                util.checkbox('defaultEncrypted', gt('Default to send encrypted when composing email'), settings),
-                                // default add signature
-                                util.checkbox('defaultSign', gt('Default adding signature to outgoing mails'), settings),
-                                // inline
-                                settings.get('advanced', false) ?
-                                    util.checkbox('defaultInline', gt('Default to using PGP inline for new mails'), settings) : [],
-                                util.compactSelect('defRemember', gt('Remember password default'), settings, this.getPasswordOptions())
-                            )
-                        )
-                    );
-                }
-            },
-            {
-                id: 'passwordManagement',
-                index: INDEX += 100,
-                render: function (baton) {
-                    this.$el.append(
-                        util.fieldset(
-                            gt('Password management'),
-                            baton.branch('buttons', null, $('<div class="form-group buttons" id="passwordDiv">'))
-                        )
-                    );
-                }
-            },
-            {
-                id: 'Advanced',
-                index: INDEX += 100,
-                render: function () {
-                    if (!guardUtil.hasGuardMailCapability()) return;
-                    var advancedBox = util.checkbox('advanced', gt('Show advanced settings'), settings);
-                    advancedBox.on('change', function () {
-                        updateAdvanced();
-                    });
-                    this.$el.append(
-                        util.fieldset(
-                            gt('Advanced'),
-                            // default to encrypt outgoing
-                            advancedBox
-                        )
-                    );
-                    this.$el.append(drawAdvanced());
-                }
+        {
+            id: 'header',
+            index: INDEX += 100,
+            render: function () {
+                this.$el.addClass('io-ox-guard-settings').append(
+                    util.header(gt('%s security settings', window.oxguarddata.productName))
+                );
             }
-        );
+        },
+        {
+            id: 'defaults',
+            index: INDEX += 100,
+            render: function () {
+                if (guardUtil.isGuest() || !guardUtil.hasGuardMailCapability()) return;   // Guests don't set defaults for sending
+                this.$el.append(
+                    $('<div class="guardDefaults">').append(
+                        util.fieldset(
+                            gt('Defaults'),
+                            // default to encrypt outgoing
+                            util.checkbox('defaultEncrypted', gt('Default to send encrypted when composing email'), settings),
+                            // default add signature
+                            util.checkbox('defaultSign', gt('Default adding signature to outgoing mails'), settings),
+                            // inline
+                            util.checkbox('defaultInline', gt('Default to using PGP inline for new mails'), settings).addClass('guardAdvanced').css('display', settings.get('advanced') ? 'block' : 'none'),
+                            util.compactSelect('defRemember', gt('Remember password default'), settings, this.getPasswordOptions())
+                        )
+                    )
+                );
+            }
+        },
+        {
+            id: 'passwordManagement',
+            index: INDEX += 100,
+            render: function (baton) {
+                this.$el.append(
+                    util.fieldset(
+                        gt('Password management'),
+                        baton.branch('buttons', null, $('<div class="form-group buttons" id="passwordDiv">'))
+                    )
+                );
+            }
+        },
+        {
+            id: 'Advanced',
+            index: INDEX += 100,
+            render: function () {
+                var advancedBox = util.checkbox('advanced', gt('Show advanced settings'), settings);
+                advancedBox.on('change', function () {
+                    updateAdvanced();
+                });
+                this.$el.append(
+                    util.fieldset(
+                        gt('Advanced'),
+                        // default to encrypt outgoing
+                        advancedBox
+                    )
+                );
+                this.$el.append(
+                    $('<div class="guardAdvanced" style="display:' + (settings.get('advanced') ? 'block' : 'none') + '">')
+                        .append(drawAdvanced()).append(drawAutocrypt()));
+                updateAdvanced();
+            }
+        }
+    );
     //
     // Buttons
     //
@@ -176,7 +177,7 @@ define('oxguard/settings/pane', [
             render: function () {
 
                 // check enabled
-                if (!window.oxguarddata.recovery || window.oxguarddata['new']) {  // If no recovery avail, then don't display reset button
+                if (!window.oxguarddata.recovery || window.oxguarddata.new) {  // If no recovery avail, then don't display reset button
                     return;
                 }
                 this.append(
@@ -198,7 +199,7 @@ define('oxguard/settings/pane', [
             render: function () {
 
                 // check enabled
-                if (!window.oxguarddata.recovery || window.oxguarddata['new']) {  // If no recovery avail, then don't display reset button
+                if (!window.oxguarddata.recovery || window.oxguarddata.new) {  // If no recovery avail, then don't display reset button
                     return;
                 }
                 this.append(
@@ -219,10 +220,10 @@ define('oxguard/settings/pane', [
             index: 400,
             render: function (baton) {
                 // check enabled
-                if (!window.oxguarddata.recovery || window.oxguarddata.settings.noDeleteRecovery || window.oxguarddata['new']) {  // If no recovery avail, then don't display reset button
+                if (!window.oxguarddata.recovery || window.oxguarddata.settings.noDeleteRecovery || window.oxguarddata.new || guardUtil.isGuest()) {  // If no recovery avail, then don't display reset button
                     return;
                 }
-                var button = $('<button type="button" class="btn btn-default" id="deleteRecovery">')
+                var button = $('<button type="button" class="btn btn-default guardAdvanced" id="deleteRecovery">')
                     //#. Option to remove the possibility of recovering your password
                     .text(gt('Delete password recovery'))
                     .on('click', openDialog);
@@ -242,11 +243,8 @@ define('oxguard/settings/pane', [
         }
     );
 
-    function drawAdvanced () {
+    function drawAdvanced() {
         var div = $('<div class="guardAdvanced" id="advancedDiv">');
-        if (!settings.get('advanced')) {
-            return div;
-        }
         $('#deleteRecovery').show();
         var downloadPublic = $('<div>');
         var downloadPublicButton = $('<button type="button" class="btn btn-default" name="downloadPublic">')
@@ -262,43 +260,81 @@ define('oxguard/settings/pane', [
             });
         }
         var recipients = '';
-        if (!guardUtil.isGuest()) {  // Guests don't manage Public keys for recipients
+        var autoCrypt = '';
+        if (guardUtil.hasGuardMailCapability()) {  // Guests don't manage Public keys for recipients
             recipients = $('<button type="button" class="btn btn-default" name="recipients">')
             .text(gt('Public keys of recipients'))
             .on('click', openDialog);
+            if (core.autoCryptEnabled()) {
+                autoCrypt = $('<button type="button" class="btn btn-default" name="autoCrypt">')
+                .text(gt('Autocrypt Keys'))
+                .on('click', openAutoCryptDialog);
+            }
         }
         function openDialog() {
             ox.load(['oxguard/settings/views/publicKeysView']).done(function (view) {
                 view.open();
             });
         }
+        function openAutoCryptDialog() {
+            ox.load(['oxguard/settings/views/autoCryptKeysView']).done(function (view) {
+                view.open();
+            });
+        }
         div.append(util.fieldset(
-                gt('Keys'), downloadPublic, userKeys, recipients
-                ));
+            gt('Keys'), downloadPublic, userKeys, recipients, autoCrypt
+        ));
         div.append(drawVersion());
         return div;
     }
 
-    function downloadPublicKey () {
+    function drawAutocrypt() {
+        if (!core.autoCryptEnabled()) return;
+        var div = $('<div class="autocryptSettings guardAdvanced">');
+        var transfer = $('<button type="button" class="btn btn-default" name="transferKeys">')
+        .text(gt('Autocrypt transfer keys'))
+        .on('click', openTransferDialog);
+        function openTransferDialog() {
+            ox.load(['oxguard/pgp/autocrypt/autocryptTransferView']).done(function (view) {
+                view.open();
+            });
+        }
+        var autoAdd = util.checkbox('autoAddAutocrypt', gt('Import autocrypt keys without asking'), settings);
+        div.append(util.fieldset(gt('Autocrypt'),
+            util.checkbox('enableAutocrypt', gt('Search incoming emails for keys in header'), settings),
+            autoAdd, transfer));
+        settings.on('change:enableAutocrypt', function () {
+            checkEnabled(autoAdd);
+        });
+        checkEnabled(autoAdd);
+        return div;
+    }
+
+    function checkEnabled(block) {
+        var enabled = settings.get('enableAutocrypt');
+        block.find('[name="autoAddAutocrypt"]').attr('disabled', !enabled);
+        block.find('label').toggleClass('disabled', !enabled);
+    }
+
+    function downloadPublicKey() {
         require(['oxguard/settings/views/downloadPrivateView'], function (downloader) {
             downloader.downloadPublic();
         });
     }
 
-    function drawVersion () {
+    function drawVersion() {
         if (_.device('small')) return ('');
         var div = $('<div class="guardVersion">');
         div.append(window.oxguarddata.version + '<br>build: ' + window.oxguarddata.server);
         return (div);
     }
 
-    function updateAdvanced () {
+    function updateAdvanced() {
         if (!settings.get('advanced')) {
-            $('#deleteRecovery').hide();
-            $('#advancedDiv').hide();
+            $('.guardAdvanced').hide();
             return;
         }
-        $('#advancedDiv').show();
+        $('.guardAdvanced').show();
         $('#advancedDiv').html(drawAdvanced());
 
     }
@@ -311,14 +347,14 @@ define('oxguard/settings/pane', [
         settings.save();
     }
 
-    function setupGuard (node, baton) {
+    function setupGuard(node, baton) {
         var div = $('<div>').addClass('io-ox-guard-settings');
         var passheader = util.header(gt('%s security settings', window.oxguarddata.productName));
         var instructions = $('<div>');
         //#. product name
         instructions.append('<p>' + gt('In order to start with %s security, you must set up a password for your secured files.', window.oxguarddata.productName) + '</p>');
         var startButton = $('<button type="button" class="btn btn-default guard-start-button">' + gt('Start') + '</button>');
-        startButton.click (function () {
+        startButton.click(function () {
             require(['oxguard/core/createKeys'], function (keys) {
                 core.metrics('settings', 'create-keys');
                 keys.createKeysWizard()
