@@ -4,7 +4,7 @@ define('oxguard/tour/main', [
     'oxguard/oxguard_core',
     'oxguard/util',
     'io.ox/core/capabilities',
-    'io.ox/backbone/mini-views/help',
+    'io.ox/backbone/mini-views/helplink',
     'oxguard/core/createKeys',
     'settings!oxguard',
     'gettext!oxguard/tour',
@@ -13,9 +13,9 @@ define('oxguard/tour/main', [
     'use strict';
 
     function writeMail() {
-        ox.registry.call('mail-compose', 'compose')
+        ox.registry.call('mail-compose', 'open')
         .done(function (e) {
-            e.app.model.set('encrypt', true);
+            e.app.view.securityModel.set('encrypt', true);
         });
     }
 
@@ -24,16 +24,12 @@ define('oxguard/tour/main', [
     }
 
     function openSettings() {
-        ox.launch('io.ox/settings/main', { id: 'oxguard/pgp' }).then(function () {
-            this.setSettingsPane({ id: 'oxguard/pgp' });
-        });
+        ox.launch('io.ox/settings/main', { id: 'oxguard' });
     }
     function setEncryptDefault() {
-        ox.launch('io.ox/settings/main', { id: 'oxguard/pgp' }).then(function () {
-            this.setSettingsPane({ id: 'oxguard/pgp' });
-            //FIXME: global settings?
-            if (window.oxguarddata.settings && !window.oxguarddata.settings.pgpdefault) {
-                $('#pgpdefault').click();
+        ox.launch('io.ox/settings/main', { id: 'oxguard' }).then(function () {
+            if (!settings.get('defaultEncrypted')) {
+                $('[name="defaultEncrypted"]').click();
             }
         });
     }
@@ -67,11 +63,11 @@ define('oxguard/tour/main', [
         tour.step({ labelNext: gt('Next') })
             .title(gt.format(gt.pgettext('tour', 'The %s module'), window.oxguarddata.productName))
             .content(gt.pgettext('tour', 'Security and privacy matters to everyone. That\'s why you can now send and receive encrypted emails by simply clicking on the lock icon.'))
-            .waitFor('.og-ready')
+            .waitFor('.og-ready', 10)
             .on('wait', function () {
                 if (!composeApp) {
                     //compose not started, yet
-                    ox.once('mail:compose:ready', function (mode, app) {
+                    ox.once('mail:NEW:ready, mail:new:ready', function (mode, app) {
                         composeApp = app;
                         //HACK: can not detect that mail compose window is rendered
                         composeApp.view.$el.addClass('og-ready');
@@ -80,7 +76,7 @@ define('oxguard/tour/main', [
                             composeApp.view.$el.find('.toggle-encryption .fa').click();
                         }, 500);
                     });
-                    ox.registry.call('mail-compose', 'compose').done(function (e) {
+                    ox.registry.call('mail-compose', 'open').done(function (e) {
                         composeApp = e.app;
                         composeApp.cid = 'compose.tour'; // Assign a CID for the app
                     });
@@ -92,7 +88,7 @@ define('oxguard/tour/main', [
         tour.once('stop', function () {
             if (composeApp && composeApp.model) {
                 //prevent app from asking about changed content
-                composeApp.model.dirty(false);
+                composeApp.view.dirty(false);
                 composeApp.quit();
             }
         });
@@ -115,8 +111,8 @@ define('oxguard/tour/main', [
         .step()
             .title((settings.get('advanced') ? gt.pgettext('tour', 'PGP Encryption Settings') : gt.pgettext('tour', 'Security Settings')))
             .content((settings.get('advanced') ?
-                    gt.pgettext('tour', 'From here you can update your encryption settings. For example you can choose to send encrypted emails by default.') :
-                    gt.pgettext('tour', 'From here, you can update your security settings.  For example, you can choose to send secure emails by default.')))
+                gt.pgettext('tour', 'From here you can update your encryption settings. For example you can choose to send encrypted emails by default.') :
+                gt.pgettext('tour', 'From here, you can update your security settings.  For example, you can choose to send secure emails by default.')))
             .waitFor('.guardDefaults')
             .spotlight('.guardDefaults', { 'padding': 10 })
             .hotspot('.guardDefaults [name="defaultEncrypted"]', { 'top': 7, 'left': 7 })
@@ -164,8 +160,8 @@ define('oxguard/tour/main', [
             .step()
             .title(gt.pgettext('tour', 'Advanced User Settings'))
             .content($('<div>').append(
-                    $('<p>').text(gt.pgettext('tour', 'Enabling Advanced PGP Features will enable key management and specifying sending formats.'))
-             ))
+                $('<p>').text(gt.pgettext('tour', 'Enabling Advanced PGP Features will enable key management and specifying sending formats.'))
+            ))
              .waitFor('[name="advanced"]')
              .hotspot('[name="advanced"]', { 'top': 7, 'left': 7 })
              .referTo($('[name="advanced"]').parent())
@@ -185,7 +181,7 @@ define('oxguard/tour/main', [
 
                 window.setTimeout(function () {
                     hotspot.add('.toggle-encryption', { 'top': 14, 'left': 7 });
-                    composeApp.model.set('encrypt', false);
+                    composeApp.view.securityModel.set('encrypt', false);
                 }, 500);
             })
             .hotspot(['#statuslock'])
@@ -193,25 +189,29 @@ define('oxguard/tour/main', [
             .on('next', function () {
                 if (composeApp && composeApp.model) {
                     //prevent app from asking about changed content
-                    composeApp.model.dirty(false);
+                    composeApp.view.dirty(false);
                     composeApp.quit();
                 }
             })
             .end();
-        if (capabilities.has('guard-drive')) {
+        if (capabilities.has('guard-drive') && capabilities.has('infostore')) {
             tour.step()
             .title(gt.pgettext('tour', 'Encrypt files'))
             .content(gt.pgettext('tour', 'You can also protect your files. Just click on Encrypt and the selected file will be stored securely.'))
             .navigateTo('io.ox/files/main')
             .waitFor('.file-list-view')
-            .hotspot('.classic-toolbar a[data-action=encrypt]', { 'top': 13, 'left': 10 })
             .on('wait', function () {
                 window.setTimeout(function () {
-                    $('.file-list-view > .list-item.selectable:not(.file-type-folder):not(.file-type-guard):first').click();
-                    window.setTimeout(function () {
-                        $('.classic-toolbar [data-action=more] ~ ul').css('display', 'block');
-                        hotspot.add('.classic-toolbar a[data-action=encrypt]', { 'top': 13, 'left': 10 });
-                    }, 500);
+                    var firstFile = $('.file-list-view > .list-item.selectable:not(.file-type-folder):not(.file-type-guard):first');
+                    if (firstFile.length > 0) {
+                        firstFile.click();
+                        window.setTimeout(function () {
+                            $('.classic-toolbar [data-action=more] ~ ul').css('display', 'block');
+                            hotspot.add('a[data-action="oxguard/encrypt"]', { 'top': 13, 'left': 10 });
+                        }, 500);
+                    } else {
+                        hotspot.add('.dropdown.more-dropdown', { 'top': 13, 'left': 10 });
+                    }
                 }, 500);
             })
             .on('next', function () {
@@ -267,6 +267,7 @@ define('oxguard/tour/main', [
         var configured = util.isGuardConfigured();
 
         if (_.device('small') || _.device('smartphone')) {
+            if (configured) return;  // no tour for mobile
             return keys.createKeys();
         }
 
@@ -294,12 +295,12 @@ define('oxguard/tour/main', [
             tour.step({ labelNext: gt('Start Setup') })
             .title(gt.format(gt.pgettext('tour', 'Setup %s'), window.oxguarddata.productName))
             .content($('<div>').append(
-                  //#. %s product name
+                //#. %s product name
                 $('<p>').text(gt.format(gt.pgettext('tour', 'Welcome to %1$s. You will now be taken on a tour, showing you how to use %1$s.'),
-                        window.oxguarddata.productName)))
+                    window.oxguarddata.productName)))
                 .append($('<p>').text(gt.format(gt.pgettext('tour', 'Firstly however, you’ll need to setup %1$s by choosing a password which will be used to encrypt or decrypt items such as email or files.'
-                        ), window.oxguarddata.productName)))
-                )
+                ), window.oxguarddata.productName)))
+            )
             .end()
         .step()
             //#. %s product name
