@@ -11,7 +11,7 @@
  * @author Julian Baeume <julian.baeume@open-xchange.com>
  */
 define('oxguard/util', [
-'io.ox/core/capabilities'
+    'io.ox/core/capabilities'
 ], function (capabilities) {
     'use strict';
 
@@ -23,7 +23,7 @@ define('oxguard/util', [
      * @return true if configured; false otherwise
      */
     api.isGuardConfigured = function () {
-        if (window.oxguarddata === undefined) return false;
+        if (window.oxguarddata === undefined || !window.oxguarddata.lang) return false;  // Make sure Guard response
         return window.oxguarddata.passcode !== 'No Key';
     };
 
@@ -34,7 +34,7 @@ define('oxguard/util', [
             def.reject();
         } else def.resolve();
         if (window.oxguarddata.passcode === 'Password Needed') {
-            require (['oxguard/core/tempPassword'], function (core) {
+            require(['oxguard/core/tempPassword'], function (core) {
                 core.createOxGuardPasswordPrompt();
             });
         }
@@ -65,5 +65,9 @@ define('oxguard/util', [
         window.oxguarddata.onload.push(loadFunction);
     };
 
+    api.hasStoredPassword = function () {
+        return (window.oxguarddata && window.oxguarddata.passcode && window.oxguarddata.passcode.length > 20);
+    };
+
     return api;
 });
