@@ -9,7 +9,8 @@ define('pgp_mail/toggle-encryption', [
 
     var ToggleEncryptionView = Backbone.View.extend({
         tagName: 'button',
-        initialize: function () {
+        initialize: function (model, mailModel) {
+            this.mailModel = mailModel;
             this.listenTo(this.model, 'change:encrypt', function (model, val) {
                 this.$('i.fa').toggleClass('encrypted', val);
                 //gt('Click to enable encryption')
@@ -23,11 +24,14 @@ define('pgp_mail/toggle-encryption', [
         },
         toggle: function () {
             if (this.encryption_forced) {
-                require (['io.ox/core/notifications'], function (notify) {
+                require(['io.ox/core/notifications'], function (notify) {
                     notify.yell('error', gt('Reply must be encrypted'));
                 });
             } else {
                 this.model.set('encrypt', !this.model.get('encrypt'));
+                if (!this.model.get('encrypt')) {  // If removing encryption, check for pgp attachments
+                    checkPGPAttachment(this.mailModel);
+                }
             }
         },
         forceEncryption: function () {
@@ -42,13 +46,12 @@ define('pgp_mail/toggle-encryption', [
                     guard = (window.oxguarddata.settings.oxguard === true);
                 }
             }
-            if (guard || this.encryption_forced)
-                {
+            if (guard || this.encryption_forced) {
                 if (!_.device('small')) {
                     this.$el.empty().append(
-                            $('<i class="fa fa-2x" aria-hidden="true">')
+                        $('<i class="fa fa-2x" aria-hidden="true">')
                             .toggleClass('encrypted', !!this.model.get('encrypt'))
-                        );
+                    );
                     this.$el.attr('title', gt('Enable Encryption'));
                 }
             }
@@ -65,20 +68,18 @@ define('pgp_mail/toggle-encryption', [
         },
         noLinkMail: function (view) {
             this.view = view;
-            checkAttLink (this.model, view);
+            checkAttLinkView(this.mailModel, view);
         },
         changed: function () {
-            var security = _.extend({}, this.model.get('security'));
-            security.encrypt = this.model.get('encrypt');
-            this.model.set('security', security);
-            this.$el.attr('title', security.encrypt ? gt('Disable Encryption') : gt('Enable Encryption'));
+            this.$el.attr('title', this.model.get('encrypt') ? gt('Disable Encryption') : gt('Enable Encryption'));
             if (this.model && this.model.get('encrypt')) {
                 showAttLink(this.view, false);
-                checkAttLink(this.model);
+                checkAttLink(this.mailModel);
                 try {
-                    var fromArray = this.model.get('from');
+                    var fromArray = this.mailModel.get('from');
+                    var from = _.isArray(fromArray[0]) ? fromArray[0][1] : fromArray[1];
                     if (fromArray && window.oxguarddata.primaryEmail !== undefined) {
-                        if (window.oxguarddata.primaryEmail !== fromArray[0][1]) {
+                        if (window.oxguarddata.primaryEmail !== from) {
                             var warn = settings.get('warnEmailDifferent');
                             if (warn === undefined || warn === false) {
                                 displayWarning();
@@ -95,14 +96,14 @@ define('pgp_mail/toggle-encryption', [
     });
 
     // Hide or show mail attachment link
-    function showAttLink (view, show) {
+    function showAttLink(view, show) {
         if (view) {
             view.$el.find('.share-attachments').toggleClass('guardDisabled', !show);
         }
     }
 
     // Check if Mail Attachment link is shown and encryption enabled
-    function checkAttLink (model, view) {
+    function checkAttLinkView(model, view) {
         if (model.get('share_attachments')) {
             if (model.get('share_attachments').enable) {
                 if (model.get('encrypt')) {
@@ -113,10 +114,10 @@ define('pgp_mail/toggle-encryption', [
     }
 
     // Show a warning if Mail Attachment Link is shown and encryption clicked
-    function checkAttLink (model) {
+    function checkAttLink(model) {
         if (model.get('share_attachments')) {
             if (model.get('share_attachments').enable) {
-                require (['io.ox/core/tk/dialogs', 'settings!io.ox/mail'], function (dialogs, mail) {
+                require(['io.ox/core/tk/dialogs', 'settings!io.ox/mail'], function (dialogs, mail) {
                     var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true, enter: 'ok' });
                     dialog.header($('<h4>').text(gt('Not Supported')));
                     var text = $('<p>').text(gt('%s is not supported with secured email and will be disabled.', mail.get('compose/shareAttachments/name')));
@@ -136,8 +137,8 @@ define('pgp_mail/toggle-encryption', [
     }
 
     // Warning that the from address is different from primary
-    function displayWarning () {
-        require (['io.ox/core/tk/dialogs'], function (dialogs) {
+    function displayWarning() {
+        require(['io.ox/core/tk/dialogs'], function (dialogs) {
             var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true, enter: 'ok' });
             dialog.header($('<h4>').text(gt('Warning')));
             var text = $('<p>').text(gt('Sending an encrypted email from an account other than %s may cause problems with the recipient being able to reply.  Consider using your primary account.', window.oxguarddata.primaryEmail));
@@ -157,6 +158,23 @@ define('pgp_mail/toggle-encryption', [
         });
     }
 
+    // Check to see if there are pgp attachments.  Checked if encryption removed
+    // Likely the recipient won't be able to open this attachment if not sent through Guard
+    function checkPGPAttachment(model) {
+        var attachments = model.get('attachments');
+        if (attachments && _.isArray(attachments.models)) {
+            attachments.models.forEach(function (attModel) {
+                if (attModel.get('file-mimetype') === 'application/pgp-encrypted' ||
+                    (attModel.get('filename') && attModel.get('filename').indexOf('.pgp') > 0)) {
+                    require(['io.ox/core/yell'], function (yell) {
+                        //#.  Warning to the user after they removed encryption from an email.  One of the attachments is a pgp item, and it will likely be unreadable to the recipient if they remove encryption
+                        yell('warning', gt('Sending encrypted attachments without encrypting the email will usually result in the attachment being unreadable by the recipient.'));
+                    });
+                }
+            });
+        }
+    }
+
     return {
         View: ToggleEncryptionView
     };
