@@ -16,11 +16,15 @@
  */
 
 
-module.exports  = function (subject, data) {
+module.exports  = async function (subject, data, signed) {
     this.waitForVisible('.io-ox-mail-window .mail-detail-pane .subject');
     this.see(subject);
     this.waitForVisible('.oxguard_icon_fa');  // Verify PGP icon
-    this.switchTo('.mail-detail-frame');
-    this.see(data);  // Check data in body
-    this.switchTo();
+    if (signed) {  // If signed, verify signed icon visible
+        this.waitForVisible('.guard_signed');
+    }
+    this.waitForElement('.mail-detail-frame');
+    within({ frame: '.mail-detail-frame' }, () => {
+        this.waitForText(data, 3);
+    });
 };
\ No newline at end of file
