@@ -16,20 +16,18 @@
  */
 const codecept = require('codeceptjs');
 
-module.exports  = function (userIndex) {
+module.exports  = function (user) {
     
         let config = codecept.config.get(),
-         webDriver = config.helpers['WebDriverIO'];
+         webDriver = config.helpers['WebDriver'];
 
         var launchURL = webDriver.url;
         if (launchURL.search('appsuite\\/?$') >= 0) launchURL = launchURL.substring(0, launchURL.search('appsuite\\/?$'));
         if (!/\/$/.test(launchURL)) launchURL += '/';
         launchURL += 'appsuite/';
 
-        var users = global.users;
-        var user = users[userIndex];
         assert(user && user.mail, "User not found");
-        this.amOnPage(launchURL + 'api/oxguard/demo?action=reset&email=' + user.mail);
+        this.amOnPage(launchURL + 'api/oxguard/demo?action=reset&email=' + user.email1);
         this.waitForVisible('body', 2000);
     
     return this;
