@@ -19,11 +19,11 @@ module.exports = function (grunt) {
                         'apps/oxguard/mail/oxguard_mail_password.js',
                         'apps/pgp_mail/util.js',
                         'apps/oxguard/mail/mail_metrics.js',
-                        'apps/oxguard/mail/mail_extensions_compose.js',
                         'apps/oxguard/mail/register_compose.js',
                         'apps/oxguard/mail/oxguard_mail_compose_core.js',
                         'apps/oxguard/util.js',
                         'apps/pgp_mail/toggle-encryption.js',
+                        'apps/oxguard/auth.js',
                         'apps/oxguard/core/passwordView.js',
                         'build/apps/oxguard/crypto/encr.js',
                         'build/apps/oxguard/crypto/jsencrypt.js',
